@@ -36,8 +36,7 @@
 /**
  * GdkClipboard:
  *
- * The `GdkClipboard` object represents data shared between applications or
- * inside an application.
+ * Represents data shared between applications or inside an application.
  *
  * To get a `GdkClipboard` object, use [method@Gdk.Display.get_clipboard] or
  * [method@Gdk.Display.get_primary_clipboard]. You can find out about the data
@@ -147,6 +146,7 @@ gdk_clipboard_finalize (GObject *object)
   GdkClipboardPrivate *priv = gdk_clipboard_get_instance_private (clipboard);
 
   g_clear_pointer (&priv->formats, gdk_content_formats_unref);
+  g_clear_object (&priv->content);
 
   G_OBJECT_CLASS (gdk_clipboard_parent_class)->finalize (object);
 }
@@ -353,7 +353,7 @@ gdk_clipboard_class_init (GdkClipboardClass *class)
   class->read_finish = gdk_clipboard_read_local_finish;
 
   /**
-   * GdkClipboard:display: (attributes org.gtk.Property.get=gdk_clipboard_get_display)
+   * GdkClipboard:display:
    *
    * The `GdkDisplay` that the clipboard belongs to.
    */
@@ -366,7 +366,7 @@ gdk_clipboard_class_init (GdkClipboardClass *class)
                          G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GdkClipboard:formats: (attributes org.gtk.Property.get=gdk_clipboard_get_formats)
+   * GdkClipboard:formats:
    *
    * The possible formats that the clipboard can provide its data in.
    */
@@ -378,7 +378,7 @@ gdk_clipboard_class_init (GdkClipboardClass *class)
                         G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GdkClipboard:local: (attributes org.gtk.Property.get=gdk_clipboard_is_local)
+   * GdkClipboard:local: (getter is_local)
    *
    * %TRUE if the contents of the clipboard are owned by this process.
    */
@@ -390,7 +390,7 @@ gdk_clipboard_class_init (GdkClipboardClass *class)
                           G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GdkClipboard:content: (attributes org.gtk.Property.get=gdk_clipboard_get_content)
+   * GdkClipboard:content:
    *
    * The `GdkContentProvider` or %NULL if the clipboard is empty or contents are
    * provided otherwise.
@@ -429,7 +429,7 @@ gdk_clipboard_init (GdkClipboard *clipboard)
 }
 
 /**
- * gdk_clipboard_get_display: (attributes org.gtk.Method.get_property=display)
+ * gdk_clipboard_get_display:
  * @clipboard: a `GdkClipboard`
  *
  * Gets the `GdkDisplay` that the clipboard was created for.
@@ -447,7 +447,7 @@ gdk_clipboard_get_display (GdkClipboard *clipboard)
 }
 
 /**
- * gdk_clipboard_get_formats: (attributes org.gtk.Method.get_property=formats)
+ * gdk_clipboard_get_formats:
  * @clipboard: a `GdkClipboard`
  *
  * Gets the formats that the clipboard can provide its current contents in.
@@ -465,7 +465,7 @@ gdk_clipboard_get_formats (GdkClipboard *clipboard)
 }
 
 /**
- * gdk_clipboard_is_local: (attributes org.gtk.Method.get_property=local)
+ * gdk_clipboard_is_local: (get-property local)
  * @clipboard: a `GdkClipboard`
  *
  * Returns if the clipboard is local.
@@ -489,7 +489,7 @@ gdk_clipboard_is_local (GdkClipboard *clipboard)
 }
 
 /**
- * gdk_clipboard_get_content: (attributes org.gtk.Method.get_property=content)
+ * gdk_clipboard_get_content:
  * @clipboard: a `GdkClipboard`
  *
  * Returns the `GdkContentProvider` currently set on @clipboard.
@@ -515,15 +515,13 @@ gdk_clipboard_get_content (GdkClipboard *clipboard)
  * @clipboard: a `GdkClipboard`
  * @io_priority: the I/O priority of the request
  * @cancellable: (nullable): optional `GCancellable` object
- * @callback: (scope async): callback to call when the request is satisfied
- * @user_data: (closure): the data to pass to callback function
+ * @callback: (scope async) (closure user_data): callback to call when the request is satisfied
+ * @user_data:: the data to pass to callback function
  *
  * Asynchronously instructs the @clipboard to store its contents remotely.
  *
  * If the clipboard is not local, this function does nothing but report success.
  *
- * The @callback must call [method@Gdk.Clipboard.store_finish].
- *
  * The purpose of this call is to preserve clipboard contents beyond the
  * lifetime of an application, so this function is typically called on
  * exit. Depending on the platform, the functionality may not be available
@@ -632,15 +630,12 @@ gdk_clipboard_read_internal (GdkClipboard        *clipboard,
  * @mime_types: (array zero-terminated=1): a %NULL-terminated array of mime types to choose from
  * @io_priority: the I/O priority of the request
  * @cancellable: (nullable): optional `GCancellable` object
- * @callback: (scope async): callback to call when the request is satisfied
- * @user_data: (closure): the data to pass to callback function
+ * @callback: (scope async) (closure user_data): callback to call when the request is satisfied
+ * @user_data: the data to pass to callback function
  *
  * Asynchronously requests an input stream to read the @clipboard's
  * contents from.
  *
- * When the operation is finished @callback will be called. You must then
- * call [method@Gdk.Clipboard.read_finish] to get the result of the operation.
- *
  * The clipboard will choose the most suitable mime type from the given list
  * to fulfill the request, preferring the ones listed first.
  */
@@ -828,15 +823,12 @@ gdk_clipboard_read_value_internal (GdkClipboard        *clipboard,
  * @type: a `GType` to read
  * @io_priority: the I/O priority of the request
  * @cancellable: (nullable): optional `GCancellable` object
- * @callback: (scope async): callback to call when the request is satisfied
- * @user_data: (closure): the data to pass to callback function
+ * @callback: (scope async) (closure user_data): callback to call when the request is satisfied
+ * @user_data: the data to pass to callback function
  *
  * Asynchronously request the @clipboard contents converted to the given
  * @type.
  *
- * When the operation is finished @callback will be called. You must then call
- * [method@Gdk.Clipboard.read_value_finish] to get the resulting `GValue`.
- *
  * For local clipboard contents that are available in the given `GType`,
  * the value will be copied directly. Otherwise, GDK will try to use
  * [func@content_deserialize_async] to convert the clipboard's data.
@@ -890,14 +882,11 @@ gdk_clipboard_read_value_finish (GdkClipboard  *clipboard,
  * gdk_clipboard_read_texture_async:
  * @clipboard: a `GdkClipboard`
  * @cancellable: (nullable): optional `GCancellable` object, %NULL to ignore.
- * @callback: (scope async): callback to call when the request is satisfied
- * @user_data: (closure): the data to pass to callback function
+ * @callback: (scope async) (closure user_data): callback to call when the request is satisfied
+ * @user_data: the data to pass to callback function
  *
  * Asynchronously request the @clipboard contents converted to a `GdkPixbuf`.
  *
- * When the operation is finished @callback will be called. You must then
- * call [method@Gdk.Clipboard.read_texture_finish] to get the result.
- *
  * This is a simple wrapper around [method@Gdk.Clipboard.read_value_async].
  * Use that function or [method@Gdk.Clipboard.read_async] directly if you
  * need more control over the operation.
@@ -955,14 +944,11 @@ gdk_clipboard_read_texture_finish (GdkClipboard  *clipboard,
  * gdk_clipboard_read_text_async:
  * @clipboard: a `GdkClipboard`
  * @cancellable: (nullable): optional `GCancellable` object
- * @callback: (scope async): callback to call when the request is satisfied
- * @user_data: (closure): the data to pass to callback function
+ * @callback: (scope async) (closure user_data): callback to call when the request is satisfied
+ * @user_data: the data to pass to callback function
  *
  * Asynchronously request the @clipboard contents converted to a string.
  *
- * When the operation is finished @callback will be called. You must then
- * call [method@Gdk.Clipboard.read_text_finish] to get the result.
- *
  * This is a simple wrapper around [method@Gdk.Clipboard.read_value_async].
  * Use that function or [method@Gdk.Clipboard.read_async] directly if you
  * need more control over the operation.
