@@ -71,7 +71,7 @@ download_memcpy (guchar          *dst_data,
   bpp = gdk_memory_format_bytes_per_pixel (dst_format);
   src_stride = dmabuf->planes[0].stride;
   src_data = src_datas[0] + dmabuf->planes[0].offset;
-  g_return_if_fail (sizes[0] >= dmabuf->planes[0].offset + (height - 1) * dst_stride + width * bpp);
+  g_return_if_fail (sizes[0] >= dmabuf->planes[0].offset + gdk_memory_format_min_buffer_size (dst_format, src_stride, width, height));
 
   if (dst_stride == src_stride)
     memcpy (dst_data, src_data, (height - 1) * dst_stride + width * bpp);
@@ -241,6 +241,108 @@ download_nv12 (guchar          *dst_data,
     }
 }
 
+static inline void
+get_uv_values16 (const YUVCoefficients *coeffs,
+                 guint16                u,
+                 guint16                v,
+                 gint64                *out_r,
+                 gint64                *out_g,
+                 gint64                *out_b)
+{
+  gint64 u2 = (gint64) u - 32767;
+  gint64 v2 = (gint64) v - 32767;
+  *out_r = coeffs->v_to_r * v2;
+  *out_g = coeffs->u_to_g * u2 + coeffs->v_to_g * v2;
+  *out_b = coeffs->u_to_b * u2;
+}
+
+static inline void
+set_rgb_values16 (guint16 rgb[3],
+                  guint16 y,
+                  gint64  r,
+                  gint64  g,
+                  gint64  b)
+{
+  gint64 y2 = (gint64) y * 65536;
+
+  rgb[0] = CLAMP ((y2 + r) >> 16, 0, 65535);
+  rgb[1] = CLAMP ((y2 + g) >> 16, 0, 65535);
+  rgb[2] = CLAMP ((y2 + b) >> 16, 0, 65535);
+}
+
+static void
+download_p010 (guchar          *dst,
+               gsize            dst_stride,
+               GdkMemoryFormat  dst_format,
+               gsize            width,
+               gsize            height,
+               const GdkDmabuf *dmabuf,
+               const guchar    *src_data[GDK_DMABUF_MAX_PLANES],
+               gsize            sizes[GDK_DMABUF_MAX_PLANES])
+{
+  const guint16 *y_data, *uv_data;
+  guint16 *dst_data;
+  gsize x, y, y_stride, uv_stride;
+  gsize U, V, X_SUB, Y_SUB;
+  guint16 SIZE, MASK;
+
+  switch (dmabuf->fourcc)
+    {
+    case DRM_FORMAT_P010:
+      U = 0; V = 1; X_SUB = 2; Y_SUB = 2;
+      SIZE = 10;
+      break;
+    case DRM_FORMAT_P012:
+      U = 0; V = 1; X_SUB = 2; Y_SUB = 2;
+      SIZE = 12;
+      break;
+    case DRM_FORMAT_P016:
+      U = 0; V = 1; X_SUB = 2; Y_SUB = 2;
+      SIZE = 16;
+      break;
+    default:
+      g_assert_not_reached ();
+      return;
+    }
+  MASK = 0xFFFF << (16 - SIZE);
+
+  y_stride = dmabuf->planes[0].stride / 2;
+  y_data = (const guint16 *) (src_data[0] + dmabuf->planes[0].offset);
+  g_return_if_fail (sizes[0] >= dmabuf->planes[0].offset + height * dmabuf->planes[0].stride);
+  uv_stride = dmabuf->planes[1].stride / 2;
+  uv_data = (const guint16 *) (src_data[1] + dmabuf->planes[1].offset);
+  g_return_if_fail (sizes[1] >= dmabuf->planes[1].offset + (height + Y_SUB - 1) / Y_SUB * dmabuf->planes[1].stride);
+  dst_data = (guint16 *) dst;
+  dst_stride /= 2;
+
+  for (y = 0; y < height; y += Y_SUB)
+    {
+      for (x = 0; x < width; x += X_SUB)
+        {
+          gint64 r, g, b;
+          gsize xs, ys;
+          guint16 u, v;
+
+          u = uv_data[x / X_SUB * 2 + U];
+          u = (u & MASK) | (u >> SIZE);
+          v = uv_data[x / X_SUB * 2 + V];
+          v = (v & MASK) | (v >> SIZE);
+          get_uv_values16 (&itu601_narrow, u, v, &r, &g, &b);
+
+          for (ys = 0; ys < Y_SUB && y + ys < height; ys++)
+            for (xs = 0; xs < X_SUB && x + xs < width; xs++)
+              {
+                guint16 y_ = y_data[x + xs + y_stride * ys];
+                y_ = (y_ & MASK) | (y_ >> SIZE);
+                set_rgb_values16 (&dst_data[3 * (x + xs) + dst_stride * ys], y_, r, g, b);
+              }
+        }
+      dst_data += Y_SUB * dst_stride;
+      y_data += Y_SUB * y_stride;
+      uv_data += uv_stride;
+    }
+}
+
 static void
 download_yuv_3 (guchar          *dst_data,
                 gsize            dst_stride,
@@ -1673,7 +1775,7 @@ static const GdkDrmFormatInfo supported_formats[] = {
     .download = NULL,
 #ifdef GDK_RENDERING_VULKAN
     .vk = {
-        .format = VK_FORMAT_G10X6_B10X6R10X6_2PLANE_420_UNORM_3PACK16,
+        .format = VK_FORMAT_G10X6_B10X6R10X6_2PLANE_422_UNORM_3PACK16,
         .swizzle = VULKAN_DEFAULT_SWIZZLE,
     },
 #endif
@@ -1682,10 +1784,10 @@ static const GdkDrmFormatInfo supported_formats[] = {
     .fourcc = DRM_FORMAT_P010,
     .memory_format = GDK_MEMORY_R16G16B16,
     .is_yuv = TRUE,
-    .download = NULL,
+    .download = download_p010,
 #ifdef GDK_RENDERING_VULKAN
     .vk = {
-        .format = VK_FORMAT_G10X6_B10X6R10X6_2PLANE_422_UNORM_3PACK16,
+        .format = VK_FORMAT_G10X6_B10X6R10X6_2PLANE_420_UNORM_3PACK16,
         .swizzle = VULKAN_DEFAULT_SWIZZLE,
     },
 #endif
@@ -1694,10 +1796,10 @@ static const GdkDrmFormatInfo supported_formats[] = {
     .fourcc = DRM_FORMAT_P012,
     .memory_format = GDK_MEMORY_R16G16B16,
     .is_yuv = TRUE,
-    .download = NULL,
+    .download = download_p010,
 #ifdef GDK_RENDERING_VULKAN
     .vk = {
-        .format = VK_FORMAT_G12X4_B12X4R12X4_2PLANE_422_UNORM_3PACK16,
+        .format = VK_FORMAT_G12X4_B12X4R12X4_2PLANE_420_UNORM_3PACK16,
         .swizzle = VULKAN_DEFAULT_SWIZZLE,
     },
 #endif
@@ -1706,10 +1808,10 @@ static const GdkDrmFormatInfo supported_formats[] = {
     .fourcc = DRM_FORMAT_P016,
     .memory_format = GDK_MEMORY_R16G16B16,
     .is_yuv = TRUE,
-    .download = NULL,
+    .download = download_p010,
 #ifdef GDK_RENDERING_VULKAN
     .vk = {
-        .format = VK_FORMAT_G16_B16R16_2PLANE_422_UNORM,
+        .format = VK_FORMAT_G16_B16R16_2PLANE_420_UNORM,
         .swizzle = VULKAN_DEFAULT_SWIZZLE,
     },
 #endif
@@ -1966,7 +2068,7 @@ gdk_dmabuf_get_mmap_formats (void)
             continue;
 
           GDK_DEBUG (DMABUF,
-                     "mmap dmabuf format %.4s:%#0" G_GINT64_MODIFIER "x",
+                     "mmap advertises dmabuf format %.4s::%016" G_GINT64_MODIFIER "x",
                      (char *) &supported_formats[i].fourcc, (guint64) DRM_FORMAT_MOD_LINEAR);
 
           gdk_dmabuf_formats_builder_add_format (builder,
@@ -1980,7 +2082,7 @@ gdk_dmabuf_get_mmap_formats (void)
   return formats;
 }
 
-static void
+static gboolean
 gdk_dmabuf_do_download_mmap (GdkTexture *texture,
                              guchar     *data,
                              gsize       stride)
@@ -1991,16 +2093,17 @@ gdk_dmabuf_do_download_mmap (GdkTexture *texture,
   gsize sizes[GDK_DMABUF_MAX_PLANES];
   gsize needs_unmap[GDK_DMABUF_MAX_PLANES] = { FALSE, };
   gsize i, j;
+  gboolean retval = FALSE;
 
   dmabuf = gdk_dmabuf_texture_get_dmabuf (GDK_DMABUF_TEXTURE (texture));
+
+  if (dmabuf->modifier != DRM_FORMAT_MOD_LINEAR)
+    return FALSE;
+
   info = get_drm_format_info (dmabuf->fourcc);
 
-  g_return_if_fail (info && info->download);
-
-  GDK_DISPLAY_DEBUG (gdk_dmabuf_texture_get_display (GDK_DMABUF_TEXTURE (texture)), DMABUF,
-                     "Using mmap for downloading %dx%d dmabuf (format %.4s:%#" G_GINT64_MODIFIER "x)",
-                     gdk_texture_get_width (texture), gdk_texture_get_height (texture),
-                     (char *)&dmabuf->fourcc, dmabuf->modifier);
+  if (!info || !info->download)
+    return FALSE;
 
   for (i = 0; i < dmabuf->n_planes; i++)
     {
@@ -2028,8 +2131,8 @@ gdk_dmabuf_do_download_mmap (GdkTexture *texture,
       if (gdk_dmabuf_ioctl (dmabuf->planes[i].fd, DMA_BUF_IOCTL_SYNC, &(struct dma_buf_sync) { DMA_BUF_SYNC_START|DMA_BUF_SYNC_READ }) < 0)
         g_warning ("Failed to sync dmabuf: %s", g_strerror (errno));
 
-      src_data[i] = mmap (NULL, sizes[i], PROT_READ, MAP_SHARED, dmabuf->planes[i].fd, dmabuf->planes[i].offset);
-      if (src_data[i] == NULL)
+      src_data[i] = mmap (NULL, sizes[i], PROT_READ, MAP_SHARED, dmabuf->planes[i].fd, 0);
+      if (src_data[i] == NULL || src_data[i] == MAP_FAILED)
         {
           g_warning ("Failed to mmap dmabuf: %s", g_strerror (errno));
           goto out;
@@ -2037,14 +2140,21 @@ gdk_dmabuf_do_download_mmap (GdkTexture *texture,
       needs_unmap[i] = TRUE;
     }
 
-    info->download (data,
-                    stride,
-                    gdk_texture_get_format (texture),
-                    gdk_texture_get_width (texture),
-                    gdk_texture_get_height (texture),
-                    dmabuf,
-                    src_data,
-                    sizes);
+  info->download (data,
+                  stride,
+                  gdk_texture_get_format (texture),
+                  gdk_texture_get_width (texture),
+                  gdk_texture_get_height (texture),
+                  dmabuf,
+                  src_data,
+                  sizes);
+
+  retval = TRUE;
+
+  GDK_DISPLAY_DEBUG (gdk_dmabuf_texture_get_display (GDK_DMABUF_TEXTURE (texture)), DMABUF,
+                     "Used mmap for downloading %dx%d dmabuf (format %.4s:%#" G_GINT64_MODIFIER "x)",
+                     gdk_texture_get_width (texture), gdk_texture_get_height (texture),
+                     (char *)&dmabuf->fourcc, dmabuf->modifier);
 
 out:
   for (i = 0; i < dmabuf->n_planes; i++)
@@ -2057,18 +2167,29 @@ out:
       if (gdk_dmabuf_ioctl (dmabuf->planes[i].fd, DMA_BUF_IOCTL_SYNC, &(struct dma_buf_sync) { DMA_BUF_SYNC_END|DMA_BUF_SYNC_READ }) < 0)
         g_warning ("Failed to sync dmabuf: %s", g_strerror (errno));
     }
+
+  return retval;
 }
 
-void
+gboolean
 gdk_dmabuf_download_mmap (GdkTexture      *texture,
                           GdkMemoryFormat  format,
+                          GdkColorState   *color_state,
                           guchar          *data,
                           gsize            stride)
 {
   GdkMemoryFormat src_format = gdk_texture_get_format (texture);
+  GdkColorState *src_color_state = gdk_texture_get_color_state (texture);
+  gboolean retval;
 
   if (format == src_format)
-    gdk_dmabuf_do_download_mmap (texture, data, stride);
+    {
+      retval = gdk_dmabuf_do_download_mmap (texture, data, stride);
+      gdk_memory_convert_color_state (data, stride, format,
+                                      src_color_state, color_state,
+                                      gdk_texture_get_width (texture),
+                                      gdk_texture_get_height (texture));
+    }
   else
     {
       unsigned int width, height;
@@ -2081,14 +2202,16 @@ gdk_dmabuf_download_mmap (GdkTexture      *texture,
       src_stride = width * gdk_memory_format_bytes_per_pixel (src_format);
       src_data = g_new (guchar, src_stride * height);
 
-      gdk_dmabuf_do_download_mmap (texture, src_data, src_stride);
+      retval = gdk_dmabuf_do_download_mmap (texture, src_data, src_stride);
 
-      gdk_memory_convert (data, stride, format,
-                          src_data, src_stride, src_format,
+      gdk_memory_convert (data, stride, format, color_state,
+                          src_data, src_stride, src_format, src_color_state,
                           width, height);
 
       g_free (src_data);
     }
+
+  return retval;
 }
 
 int
@@ -2372,3 +2495,20 @@ gdk_dmabuf_is_disjoint (const GdkDmabuf *dmabuf)
 }
 
 #endif  /* HAVE_DMABUF */
+
+void
+gdk_dmabuf_close_fds (GdkDmabuf *dmabuf)
+{
+  guint i, j;
+
+  for (i = 0; i < dmabuf->n_planes; i++)
+    {
+      for (j = 0; j < i; j++)
+        {
+          if (dmabuf->planes[i].fd == dmabuf->planes[j].fd)
+            break;
+        }
+      if (i == j)
+        g_close (dmabuf->planes[i].fd, NULL);
+    }
+}
