@@ -21,7 +21,6 @@
 
 #include "gdkconfig.h"
 
-#include <OpenGL/gl3.h>
 #include <OpenGL/CGLIOSurface.h>
 #include <QuartzCore/QuartzCore.h>
 
@@ -243,7 +242,7 @@ gdk_macos_gl_context_allocate (GdkMacosGLContext *self)
     return;
 
   /* Alter to an opaque surface if necessary */
-  opaque = _gdk_macos_surface_is_opaque (GDK_MACOS_SURFACE (surface));
+  opaque = gdk_surface_is_opaque (surface);
   if (opaque != self->last_opaque)
     {
       self->last_opaque = !!opaque;
@@ -323,12 +322,12 @@ gdk_macos_gl_context_release (GdkMacosGLContext *self)
 }
 
 static CGLPixelFormatObj
-create_pixel_format (int      major,
-                     int      minor,
-                     GError **error)
+create_pixel_format (GdkGLVersion  *version,
+                     gboolean      *out_legacy,
+                     GError       **error)
 {
   CGLPixelFormatAttribute attrs[] = {
-    kCGLPFAOpenGLProfile, (CGLPixelFormatAttribute)kCGLOGLPVersion_Legacy,
+    kCGLPFAOpenGLProfile, 0,
     kCGLPFAAllowOfflineRenderers, /* allow sharing across GPUs */
     kCGLPFADepthSize, 0,
     kCGLPFAStencilSize, 0,
@@ -339,14 +338,28 @@ create_pixel_format (int      major,
   CGLPixelFormatObj format = NULL;
   GLint n_format = 1;
 
-  if (major == 3 && minor == 2)
-    attrs[1] = (CGLPixelFormatAttribute)kCGLOGLPVersion_GL3_Core;
-  else if (major == 4 && minor == 1)
-    attrs[1] = (CGLPixelFormatAttribute)kCGLOGLPVersion_GL4_Core;
+  *out_legacy = FALSE;
 
+  if (gdk_gl_version_get_major (version) >= 4)
+    {
+      attrs[1] = (CGLPixelFormatAttribute)kCGLOGLPVersion_GL4_Core;
+      if (CHECK (error, CGLChoosePixelFormat (attrs, &format, &n_format)))
+        return g_steal_pointer (&format);
+    }
+
+  if (gdk_gl_version_greater_equal (version, &GDK_GL_MIN_GL_VERSION))
+    {
+      attrs[1] = (CGLPixelFormatAttribute)kCGLOGLPVersion_GL3_Core;
+      if (CHECK (error, CGLChoosePixelFormat (attrs, &format, &n_format)))
+        return g_steal_pointer (&format);
+    }
+
+  attrs[1] = (CGLPixelFormatAttribute) kCGLOGLPVersion_Legacy;
   if (!CHECK (error, CGLChoosePixelFormat (attrs, &format, &n_format)))
     return NULL;
 
+  *out_legacy = TRUE;
+
   return g_steal_pointer (&format);
 }
 
@@ -366,7 +379,8 @@ gdk_macos_gl_context_real_realize (GdkGLContext  *context,
   GLint validate = 0;
   GLint renderer_id = 0;
   GLint swapRect[4];
-  int major, minor;
+  GdkGLVersion min_version, version;
+  gboolean legacy;
 
   g_assert (GDK_IS_MACOS_GL_CONTEXT (self));
 
@@ -378,10 +392,10 @@ gdk_macos_gl_context_real_realize (GdkGLContext  *context,
 
   existing = CGLGetCurrentContext ();
 
-  gdk_gl_context_get_clipped_version (context,
-                                      GDK_GL_MIN_GL_VERSION_MAJOR,
-                                      GDK_GL_MIN_GL_VERSION_MINOR,
-                                      &major, &minor);
+  gdk_gl_context_get_matching_version (context,
+                                       GDK_GL_API_GL,
+                                       FALSE,
+                                       &min_version);
 
   display = gdk_gl_context_get_display (context);
   shared = gdk_display_get_gl_context (display);
@@ -400,9 +414,9 @@ gdk_macos_gl_context_real_realize (GdkGLContext  *context,
 
   GDK_DISPLAY_DEBUG (display, OPENGL,
                      "Creating CGLContextObj (version %d.%d)",
-                     major, minor);
+                     gdk_gl_version_get_major (&min_version), gdk_gl_version_get_minor (&min_version));
 
-  if (!(pixelFormat = create_pixel_format (major, minor, error)))
+  if (!(pixelFormat = create_pixel_format (&min_version, &legacy, error)))
     return 0;
 
   if (!CHECK (error, CGLCreateContext (pixelFormat, shared_gl_context, &cgl_context)))
@@ -414,6 +428,13 @@ gdk_macos_gl_context_real_realize (GdkGLContext  *context,
   CGLSetCurrentContext (cgl_context);
   CGLReleasePixelFormat (pixelFormat);
 
+  gdk_gl_version_init_epoxy (&version);
+  if (!gdk_gl_version_greater_equal (&version, &min_version))
+    {
+      CGLReleaseContext (cgl_context);
+      return 0;
+    }
+
   if (validate)
     CHECK (NULL, CGLEnable (cgl_context, kCGLCEStateValidation));
 
@@ -445,6 +466,9 @@ gdk_macos_gl_context_real_realize (GdkGLContext  *context,
                      cgl_context,
                      get_renderer_name (renderer_id));
 
+  gdk_gl_context_set_version (context, &version);
+  gdk_gl_context_set_is_legacy (context, legacy);
+
   self->cgl_context = g_steal_pointer (&cgl_context);
 
   if (existing != NULL)
@@ -454,18 +478,18 @@ gdk_macos_gl_context_real_realize (GdkGLContext  *context,
 }
 
 static void
-gdk_macos_gl_context_begin_frame (GdkDrawContext *context,
-                                  gboolean        prefers_high_depth,
-                                  cairo_region_t *region)
+gdk_macos_gl_context_begin_frame (GdkDrawContext  *context,
+                                  GdkMemoryDepth   depth,
+                                  cairo_region_t  *region,
+                                  GdkColorState  **out_color_state,
+                                  GdkMemoryDepth  *out_depth)
 {
   GdkMacosGLContext *self = (GdkMacosGLContext *)context;
   GdkMacosBuffer *buffer;
-  cairo_region_t *copy;
   GdkSurface *surface;
 
   g_assert (GDK_IS_MACOS_GL_CONTEXT (self));
 
-  copy = cairo_region_copy (region);
   surface = gdk_draw_context_get_surface (context);
   buffer = _gdk_macos_surface_get_buffer (GDK_MACOS_SURFACE (surface));
 
@@ -476,7 +500,7 @@ gdk_macos_gl_context_begin_frame (GdkDrawContext *context,
   gdk_gl_context_make_current (GDK_GL_CONTEXT (self));
   gdk_macos_gl_context_allocate (self);
 
-  GDK_DRAW_CONTEXT_CLASS (gdk_macos_gl_context_parent_class)->begin_frame (context, prefers_high_depth, region);
+  GDK_DRAW_CONTEXT_CLASS (gdk_macos_gl_context_parent_class)->begin_frame (context, depth, region, out_color_state, out_depth);
 
   gdk_gl_context_make_current (GDK_GL_CONTEXT (self));
   CHECK_GL (NULL, glBindFramebuffer (GL_FRAMEBUFFER, self->fbo));
@@ -523,6 +547,11 @@ gdk_macos_gl_context_end_frame (GdkDrawContext *context,
   [CATransaction commit];
 }
 
+static void
+gdk_macos_gl_context_empty_frame (GdkDrawContext *draw_context)
+{
+}
+
 static void
 gdk_macos_gl_context_surface_resized (GdkDrawContext *draw_context)
 {
@@ -550,6 +579,14 @@ gdk_macos_gl_context_clear_current (GdkGLContext *context)
   return TRUE;
 }
 
+static gboolean
+gdk_macos_gl_context_is_current (GdkGLContext *context)
+{
+  GdkMacosGLContext *self = GDK_MACOS_GL_CONTEXT (context);
+
+  return self->cgl_context == CGLGetCurrentContext ();
+}
+
 static gboolean
 gdk_macos_gl_context_make_current (GdkGLContext *context,
                                    gboolean      surfaceless)
@@ -568,7 +605,7 @@ gdk_macos_gl_context_make_current (GdkGLContext *context,
        * are submitted.
        *
        * TODO: investigate if we need this because we may switch contexts
-       *       durring composition and only need it when returning to a
+       *       during composition and only need it when returning to a
        *       previous context that uses the other context.
        */
       if (current != NULL)
@@ -637,10 +674,12 @@ gdk_macos_gl_context_class_init (GdkMacosGLContextClass *klass)
 
   draw_context_class->begin_frame = gdk_macos_gl_context_begin_frame;
   draw_context_class->end_frame = gdk_macos_gl_context_end_frame;
+  draw_context_class->empty_frame = gdk_macos_gl_context_empty_frame;
   draw_context_class->surface_resized = gdk_macos_gl_context_surface_resized;
 
   gl_class->get_damage = gdk_macos_gl_context_get_damage;
   gl_class->clear_current = gdk_macos_gl_context_clear_current;
+  gl_class->is_current = gdk_macos_gl_context_is_current;
   gl_class->make_current = gdk_macos_gl_context_make_current;
   gl_class->realize = gdk_macos_gl_context_real_realize;
   gl_class->get_default_framebuffer = gdk_macos_gl_context_get_default_framebuffer;
