@@ -115,7 +115,11 @@ const static struct {
   { 105, GDK_KEY_F13 },
   { 107, GDK_KEY_F14 },
   { 113, GDK_KEY_F15 },
-  { 106, GDK_KEY_F16 }
+  { 106, GDK_KEY_F16 },
+  {  64, GDK_KEY_F17 },
+  {  79, GDK_KEY_F18 },
+  {  80, GDK_KEY_F19 },
+  {  90, GDK_KEY_F20 }
 };
 
 const static struct {
@@ -276,10 +280,8 @@ gdk_macos_keymap_update (GdkMacosKeymap *self)
         {
           UInt32 state = 0;
           OSStatus err;
-          UInt16 key_code;
           UniChar uc;
 
-          key_code = modifiers[j] | i;
           err = UCKeyTranslate (chr_data, i, kUCKeyActionDisplay,
                                 (modifiers[j] >> 8) & 0xFF,
                                 LMGetKbdType(),
@@ -369,7 +371,7 @@ gdk_macos_keymap_update (GdkMacosKeymap *self)
       if (p[0] == known_numeric_keys[i].normal_keyval)
         p[0] = known_numeric_keys[i].keypad_keyval;
     }
-      
+
   for (i = 0; i < G_N_ELEMENTS (jis_keys); i++)
     {
       p = keyval_array + jis_keys[i].keycode * KEYVALS_PER_KEYCODE;
