@@ -39,7 +39,7 @@ struct _GdkWin32CairoContext
   GdkCairoContext parent_instance;
 
   /* Set to TRUE when double-buffering is used.
-   * Layered windows use their own, custom double-buffering
+   * Layered HWNDs use their own, custom double-buffering
    * code that is unaffected by this flag.
    */
   guint            double_buffered : 1;
@@ -51,11 +51,11 @@ struct _GdkWin32CairoContext
   int              db_width;
   int              db_height;
 
-  /* Surface for the window DC */
-  cairo_surface_t *window_surface;
+  /* Surface for the underlying window DC */
+  cairo_surface_t *hwnd_surface;
   /* A reference to db_surface (when double-buffering).
    * When not using double-buffering this is a reference
-   * to window_surface.
+   * to hwnd_surface.
    */
   cairo_surface_t *paint_surface;
 };
