@@ -1224,32 +1224,31 @@ gtk_at_spi_context_platform_change (GtkATContext                *ctx,
 {
   GtkAtSpiContext *self = GTK_AT_SPI_CONTEXT (ctx);
   GtkAccessible *accessible = gtk_at_context_get_accessible (ctx);
-  GtkWidget *widget;
 
-  if (!GTK_IS_WIDGET (accessible))
-    return;
-
-  widget = GTK_WIDGET (accessible);
-  if (!gtk_widget_get_realized (widget))
+  /* Do not emit state changes for unrealized widgets; this may happen during
+   * construction, but since the widget is not realized, there's nothing to be
+   * perceived
+   */
+  if (GTK_IS_WIDGET (accessible) && !gtk_widget_get_realized (GTK_WIDGET (accessible)))
     return;
 
   if (changed_platform & GTK_ACCESSIBLE_PLATFORM_CHANGE_FOCUSABLE)
     {
-      gboolean state = gtk_accessible_get_platform_state (GTK_ACCESSIBLE (widget),
+      gboolean state = gtk_accessible_get_platform_state (accessible,
                                                           GTK_ACCESSIBLE_PLATFORM_STATE_FOCUSABLE);
       emit_state_changed (self, "focusable", state);
     }
 
   if (changed_platform & GTK_ACCESSIBLE_PLATFORM_CHANGE_FOCUSED)
     {
-      gboolean state = gtk_accessible_get_platform_state (GTK_ACCESSIBLE (widget),
+      gboolean state = gtk_accessible_get_platform_state (accessible,
                                                           GTK_ACCESSIBLE_PLATFORM_STATE_FOCUSED);
       emit_state_changed (self, "focused", state);
     }
 
   if (changed_platform & GTK_ACCESSIBLE_PLATFORM_CHANGE_ACTIVE)
     {
-      gboolean state = gtk_accessible_get_platform_state (GTK_ACCESSIBLE (widget),
+      gboolean state = gtk_accessible_get_platform_state (accessible,
                                                           GTK_ACCESSIBLE_PLATFORM_STATE_ACTIVE);
       emit_state_changed (self, "active", state);
 
