@@ -248,20 +248,31 @@ parse_compose_sequence (const char *seq,
 
       if (is_codepoint (match))
         {
-          keyval = gdk_unicode_to_keyval ((gunichar) g_ascii_strtoll (match + 1, NULL, 16));
-          if (keyval > 0xffff)
-            g_warning ("Can't handle >16bit keyvals");
+          gunichar ch = (gunichar) g_ascii_strtoll (match + 1, NULL, 16);
+          if (ch > 0xffff)
+            g_warning ("Can't handle > 16bit Unicode codepoints");
 
-          sequence[n] = (guint16) keyval;
+          keyval = gdk_unicode_to_keyval (ch);
+          if (keyval > 0xffff &&
+              gdk_keyval_to_unicode (keyval & 0xffff) != 0)
+            {
+              g_warning ("Can't handle Unicode codepoint %x", ch);
+              keyval = 0;
+            }
+
+          sequence[n] = ch;
           sequence[n + 1] = 0;
         }
       else
         {
           keyval = gdk_keyval_from_name (match);
           if (keyval > 0xffff)
-            g_warning ("Can't handle >16bit keyvals");
+            {
+              g_warning ("Can't handle >16bit keyvals");
+              keyval = 0;
+            }
 
-          sequence[n] = (guint16) keyval;
+          sequence[n] = keyval;
           sequence[n + 1] = 0;
         }
 
@@ -980,12 +991,11 @@ parser_get_compose_table (GtkComposeParser *parser)
 
       if (sequence[0] != current_first)
         {
-          g_assert (sequence[0] <= 0xffff);
           if (current_first != 0)
             first_pos += index_rowstride;
-          current_first = (guint16)sequence[0];
+          current_first = sequence[0];
 
-          data[first_pos] = (guint16)sequence[0];
+          data[first_pos] = sequence[0] & 0xffff;
 
           for (i = 1; i < index_rowstride; i++)
             data[first_pos + i] = rest_pos;
@@ -994,8 +1004,7 @@ parser_get_compose_table (GtkComposeParser *parser)
       for (i = 1; i < len; i++)
         {
           g_assert (sequence[i] != 0);
-          g_assert (sequence[i] <= 0xffff);
-          data[rest_pos + i - 1] = (guint16) sequence[i];
+          data[rest_pos + i - 1] = sequence[i] & 0xffff;
         }
 
       g_assert (encoded_value != 0);
@@ -1254,6 +1263,16 @@ gtk_compose_table_new_with_data (const guint16 *data,
   return compose_table;
 }
 
+static guint
+gtk_compose_key_flag (guint key)
+{
+  const char *name = gdk_keyval_name (key);
+  if (!name || g_str_has_prefix (name, "0x"))
+    return 0x1000000;
+
+  return 0;
+}
+
 static int
 compare_seq (const void *key, const void *value)
 {
@@ -1263,10 +1282,13 @@ compare_seq (const void *key, const void *value)
 
   while (keysyms[i])
     {
-      if (keysyms[i] < seq[i])
-        return -1;
-      else if (keysyms[i] > seq[i])
-        return 1;
+      guint keysym = seq[i];
+      guint flag = gtk_compose_key_flag (keysym);
+
+      if (keysyms[i] < (keysym + flag))
+        return (0xffff & keysyms[i]) - keysym;
+      else if (keysyms[i]> (keysym + flag))
+        return (0xffff & keysyms[i]) - keysym;
 
       i++;
     }
@@ -1279,11 +1301,13 @@ compare_seq_index (const void *key, const void *value)
 {
   const guint *keysyms = key;
   const guint16 *seq = value;
+  guint keysym = seq[0];
+  guint flag = gtk_compose_key_flag (keysym);
 
-  if (keysyms[0] < seq[0])
-    return -1;
-  else if (keysyms[0] > seq[0])
-    return 1;
+  if (keysyms[0] < (keysym + flag))
+    return (0xffff & keysyms[0]) - keysym;
+  else if (keysyms[0] > (keysym + flag))
+    return (0xffff & keysyms[0]) - keysym;
 
   return 0;
 }
@@ -1510,7 +1534,7 @@ gtk_compose_table_foreach (const GtkComposeTable      *table,
  * are added and we need to update the upper limit.
  */
 #define IS_DEAD_KEY(k) \
-    ((k) >= GDK_KEY_dead_grave && (k) <= GDK_KEY_dead_greek)
+    ((k) >= GDK_KEY_dead_grave && (k) <= GDK_KEY_dead_hamza)
 
 gboolean
 gtk_check_algorithmically (const guint *compose_buffer,
@@ -1605,6 +1629,7 @@ gtk_check_algorithmically (const guint *compose_buffer,
             CASE (U, 0x367);
             CASE (small_schwa, 0x1DEA);
             CASE (capital_schwa, 0x1DEA);
+            CASE (hamza, 0x654);
 #undef CASE
             default:
               g_string_append_unichar (input, gdk_keyval_to_unicode (compose_buffer[i]));
