@@ -84,7 +84,7 @@ gtk_css_style_property_register (const char *                   name,
 
   node->parse_value = parse_value;
 
-  _gtk_css_value_unref (initial_value);
+  gtk_css_value_unref (initial_value);
 
   g_assert (_gtk_css_style_property_get_id (node) == expected_id);
 }
@@ -95,7 +95,7 @@ static GtkCssValue *
 color_parse (GtkCssStyleProperty *property,
              GtkCssParser        *parser)
 {
-  return _gtk_css_color_value_parse (parser);
+  return gtk_css_color_value_parse (parser);
 }
 
 static GtkCssValue *
@@ -163,12 +163,12 @@ font_weight_parse (GtkCssStyleProperty *property,
   value = gtk_css_font_weight_value_try_parse (parser);
   if (value == NULL)
     {
-      value = _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER | GTK_CSS_POSITIVE_ONLY);
+      value = gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER | GTK_CSS_POSITIVE_ONLY);
       if (value == NULL)
         return NULL;
 
-      if (_gtk_css_number_value_get (value, 100) < 1 || 
-          _gtk_css_number_value_get (value, 100) > 1000)
+      if (gtk_css_number_value_get (value, 100) < 1 || 
+          gtk_css_number_value_get (value, 100) > 1000)
         {
           gtk_css_parser_error_value (parser, "Font weight values must be between 1 and 1000");
           g_clear_pointer (&value, gtk_css_value_unref);
@@ -240,9 +240,10 @@ parse_css_direction (GtkCssStyleProperty *property,
 
 static GtkCssValue *
 opacity_parse (GtkCssStyleProperty *property,
-	       GtkCssParser        *parser)
+               GtkCssParser        *parser)
 {
-  return _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER);
+  return gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER
+                                             | GTK_CSS_PARSE_PERCENT);
 }
 
 static GtkCssValue *
@@ -285,10 +286,10 @@ static GtkCssValue *
 icon_size_parse (GtkCssStyleProperty *property,
 		 GtkCssParser        *parser)
 {
-  return _gtk_css_number_value_parse (parser, 
-                                      GTK_CSS_PARSE_LENGTH
-                                      | GTK_CSS_PARSE_PERCENT
-                                      | GTK_CSS_POSITIVE_ONLY);
+  return gtk_css_number_value_parse (parser, 
+                                     GTK_CSS_PARSE_LENGTH
+                                     | GTK_CSS_PARSE_PERCENT
+                                     | GTK_CSS_POSITIVE_ONLY);
 }
 
 static GtkCssValue *
@@ -314,7 +315,7 @@ static GtkCssValue *
 parse_letter_spacing (GtkCssStyleProperty *property,
                       GtkCssParser        *parser)
 {
-  return _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_LENGTH);
+  return gtk_css_number_value_parse (parser, GTK_CSS_PARSE_LENGTH);
 }
 
 static gboolean
@@ -597,7 +598,7 @@ static GtkCssValue *
 dpi_parse (GtkCssStyleProperty *property,
 	   GtkCssParser        *parser)
 {
-  return _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER);
+  return gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER);
 }
 
 GtkCssValue *
@@ -609,10 +610,10 @@ gtk_css_font_size_value_parse (GtkCssParser *parser)
   if (value)
     return value;
 
-  return _gtk_css_number_value_parse (parser,
-                                      GTK_CSS_PARSE_LENGTH
-                                      | GTK_CSS_PARSE_PERCENT
-                                      | GTK_CSS_POSITIVE_ONLY);
+  return gtk_css_number_value_parse (parser,
+                                     GTK_CSS_PARSE_LENGTH
+                                     | GTK_CSS_PARSE_PERCENT
+                                     | GTK_CSS_POSITIVE_ONLY);
 }
 
 static GtkCssValue *
@@ -626,8 +627,8 @@ static GtkCssValue *
 outline_parse (GtkCssStyleProperty *property,
                GtkCssParser        *parser)
 {
-  return _gtk_css_number_value_parse (parser,
-                                      GTK_CSS_PARSE_LENGTH);
+  return gtk_css_number_value_parse (parser,
+                                     GTK_CSS_PARSE_LENGTH);
 }
 
 static GtkCssValue *
@@ -674,9 +675,9 @@ static GtkCssValue *
 minmax_parse (GtkCssStyleProperty *property,
               GtkCssParser        *parser)
 {
-  return _gtk_css_number_value_parse (parser,
-                                      GTK_CSS_PARSE_LENGTH
-                                      | GTK_CSS_POSITIVE_ONLY);
+  return gtk_css_number_value_parse (parser,
+                                     GTK_CSS_PARSE_LENGTH
+                                     | GTK_CSS_POSITIVE_ONLY);
 }
 
 static GtkCssValue *
@@ -705,7 +706,7 @@ transition_property_parse (GtkCssStyleProperty *property,
 static GtkCssValue *
 transition_time_parse_one (GtkCssParser *parser)
 {
-  return _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_TIME);
+  return gtk_css_number_value_parse (parser, GTK_CSS_PARSE_TIME);
 }
 
 static GtkCssValue *
@@ -726,9 +727,9 @@ static GtkCssValue *
 iteration_count_parse_one (GtkCssParser *parser)
 {
   if (gtk_css_parser_try_ident (parser, "infinite"))
-    return _gtk_css_number_value_new (HUGE_VAL, GTK_CSS_NUMBER);
+    return gtk_css_number_value_new (HUGE_VAL, GTK_CSS_NUMBER);
 
-  return _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER | GTK_CSS_POSITIVE_ONLY);
+  return gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER | GTK_CSS_POSITIVE_ONLY);
 }
 
 static GtkCssValue *
@@ -742,26 +743,25 @@ static GtkCssValue *
 parse_margin (GtkCssStyleProperty *property,
               GtkCssParser        *parser)
 {
-  return _gtk_css_number_value_parse (parser,
-                                      GTK_CSS_PARSE_LENGTH);
+  return gtk_css_number_value_parse (parser, GTK_CSS_PARSE_LENGTH);
 }
 
 static GtkCssValue *
 parse_padding (GtkCssStyleProperty *property,
                GtkCssParser        *parser)
 {
-  return _gtk_css_number_value_parse (parser,
-                                      GTK_CSS_POSITIVE_ONLY
-                                      | GTK_CSS_PARSE_LENGTH);
+  return gtk_css_number_value_parse (parser,
+                                     GTK_CSS_POSITIVE_ONLY
+                                     | GTK_CSS_PARSE_LENGTH);
 }
 
 static GtkCssValue *
 parse_border_width (GtkCssStyleProperty *property,
                     GtkCssParser        *parser)
 {
-  return _gtk_css_number_value_parse (parser,
-                                      GTK_CSS_POSITIVE_ONLY
-                                      | GTK_CSS_PARSE_LENGTH);
+  return gtk_css_number_value_parse (parser,
+                                     GTK_CSS_POSITIVE_ONLY
+                                     | GTK_CSS_PARSE_LENGTH);
 }
 
 static GtkCssValue *
@@ -854,7 +854,7 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_INHERIT | GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE | GTK_CSS_AFFECTS_TEXT_SIZE,
                                           dpi_parse,
-                                          _gtk_css_number_value_new (96.0, GTK_CSS_NUMBER));
+                                          gtk_css_number_value_new (96.0, GTK_CSS_NUMBER));
   gtk_css_style_property_register        ("font-size",
                                           GTK_CSS_PROPERTY_FONT_SIZE,
                                           GTK_STYLE_PROPERTY_INHERIT | GTK_STYLE_PROPERTY_ANIMATED,
@@ -895,7 +895,7 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_INHERIT | GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_TEXT_SIZE,
                                           font_weight_parse,
-                                          _gtk_css_number_value_new (PANGO_WEIGHT_NORMAL, GTK_CSS_NUMBER));
+                                          gtk_css_number_value_new (PANGO_WEIGHT_NORMAL, GTK_CSS_NUMBER));
   gtk_css_style_property_register        ("font-stretch",
                                           GTK_CSS_PROPERTY_FONT_STRETCH,
                                           GTK_STYLE_PROPERTY_INHERIT,
@@ -908,7 +908,7 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_INHERIT | GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_TEXT_ATTRS | GTK_CSS_AFFECTS_TEXT_SIZE,
                                           parse_letter_spacing,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
 
   gtk_css_style_property_register        ("text-decoration-line",
                                           GTK_CSS_PROPERTY_TEXT_DECORATION_LINE,
@@ -921,7 +921,7 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_TEXT_ATTRS,
                                           color_parse,
-                                          _gtk_css_color_value_new_current_color ());
+                                          gtk_css_color_value_new_current_color ());
   gtk_css_style_property_register        ("text-decoration-style",
                                           GTK_CSS_PROPERTY_TEXT_DECORATION_STYLE,
                                           0,
@@ -995,49 +995,49 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE,
                                           parse_margin,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   gtk_css_style_property_register        ("margin-left",
                                           GTK_CSS_PROPERTY_MARGIN_LEFT,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE,
                                           parse_margin,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   gtk_css_style_property_register        ("margin-bottom",
                                           GTK_CSS_PROPERTY_MARGIN_BOTTOM,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE,
                                           parse_margin,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   gtk_css_style_property_register        ("margin-right",
                                           GTK_CSS_PROPERTY_MARGIN_RIGHT,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE,
                                           parse_margin,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   gtk_css_style_property_register        ("padding-top",
                                           GTK_CSS_PROPERTY_PADDING_TOP,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE,
                                           parse_padding,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   gtk_css_style_property_register        ("padding-left",
                                           GTK_CSS_PROPERTY_PADDING_LEFT,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE,
                                           parse_padding,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   gtk_css_style_property_register        ("padding-bottom",
                                           GTK_CSS_PROPERTY_PADDING_BOTTOM,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE,
                                           parse_padding,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   gtk_css_style_property_register        ("padding-right",
                                           GTK_CSS_PROPERTY_PADDING_RIGHT,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE,
                                           parse_padding,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   /* IMPORTANT: the border-width properties must come after border-style properties,
    * they depend on them for their value computation.
    */
@@ -1052,7 +1052,7 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BORDER | GTK_CSS_AFFECTS_SIZE,
                                           parse_border_width,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   gtk_css_style_property_register        ("border-left-style",
                                           GTK_CSS_PROPERTY_BORDER_LEFT_STYLE,
                                           0,
@@ -1064,7 +1064,7 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BORDER | GTK_CSS_AFFECTS_SIZE,
                                           parse_border_width,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   gtk_css_style_property_register        ("border-bottom-style",
                                           GTK_CSS_PROPERTY_BORDER_BOTTOM_STYLE,
                                           0,
@@ -1076,7 +1076,7 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BORDER | GTK_CSS_AFFECTS_SIZE,
                                           parse_border_width,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   gtk_css_style_property_register        ("border-right-style",
                                           GTK_CSS_PROPERTY_BORDER_RIGHT_STYLE,
                                           0,
@@ -1088,36 +1088,36 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BORDER | GTK_CSS_AFFECTS_SIZE,
                                           parse_border_width,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
 
   gtk_css_style_property_register        ("border-top-left-radius",
                                           GTK_CSS_PROPERTY_BORDER_TOP_LEFT_RADIUS,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BACKGROUND | GTK_CSS_AFFECTS_BORDER,
                                           border_corner_radius_value_parse,
-                                          _gtk_css_corner_value_new (_gtk_css_number_value_new (0, GTK_CSS_PX),
-                                                                     _gtk_css_number_value_new (0, GTK_CSS_PX)));
+                                          _gtk_css_corner_value_new (gtk_css_number_value_new (0, GTK_CSS_PX),
+                                                                     gtk_css_number_value_new (0, GTK_CSS_PX)));
   gtk_css_style_property_register        ("border-top-right-radius",
                                           GTK_CSS_PROPERTY_BORDER_TOP_RIGHT_RADIUS,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BACKGROUND | GTK_CSS_AFFECTS_BORDER,
                                           border_corner_radius_value_parse,
-                                          _gtk_css_corner_value_new (_gtk_css_number_value_new (0, GTK_CSS_PX),
-                                                                     _gtk_css_number_value_new (0, GTK_CSS_PX)));
+                                          _gtk_css_corner_value_new (gtk_css_number_value_new (0, GTK_CSS_PX),
+                                                                     gtk_css_number_value_new (0, GTK_CSS_PX)));
   gtk_css_style_property_register        ("border-bottom-right-radius",
                                           GTK_CSS_PROPERTY_BORDER_BOTTOM_RIGHT_RADIUS,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BACKGROUND | GTK_CSS_AFFECTS_BORDER,
                                           border_corner_radius_value_parse,
-                                          _gtk_css_corner_value_new (_gtk_css_number_value_new (0, GTK_CSS_PX),
-                                                                     _gtk_css_number_value_new (0, GTK_CSS_PX)));
+                                          _gtk_css_corner_value_new (gtk_css_number_value_new (0, GTK_CSS_PX),
+                                                                     gtk_css_number_value_new (0, GTK_CSS_PX)));
   gtk_css_style_property_register        ("border-bottom-left-radius",
                                           GTK_CSS_PROPERTY_BORDER_BOTTOM_LEFT_RADIUS,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BACKGROUND | GTK_CSS_AFFECTS_BORDER,
                                           border_corner_radius_value_parse,
-                                          _gtk_css_corner_value_new (_gtk_css_number_value_new (0, GTK_CSS_PX),
-                                                                     _gtk_css_number_value_new (0, GTK_CSS_PX)));
+                                          _gtk_css_corner_value_new (gtk_css_number_value_new (0, GTK_CSS_PX),
+                                                                     gtk_css_number_value_new (0, GTK_CSS_PX)));
 
   gtk_css_style_property_register        ("outline-style",
                                           GTK_CSS_PROPERTY_OUTLINE_STYLE,
@@ -1130,13 +1130,13 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_OUTLINE,
                                           parse_border_width,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   gtk_css_style_property_register        ("outline-offset",
                                           GTK_CSS_PROPERTY_OUTLINE_OFFSET,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_OUTLINE,
                                           outline_parse,
-                                          _gtk_css_number_value_new (0.0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0.0, GTK_CSS_PX));
   gtk_css_style_property_register        ("background-clip",
                                           GTK_CSS_PROPERTY_BACKGROUND_CLIP,
                                           0,
@@ -1160,39 +1160,39 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BACKGROUND,
                                           background_position_parse,
-                                          _gtk_css_position_value_new (_gtk_css_number_value_new (0, GTK_CSS_PERCENT),
-                                                                       _gtk_css_number_value_new (0, GTK_CSS_PERCENT)));
+                                          _gtk_css_position_value_new (gtk_css_number_value_new (0, GTK_CSS_PERCENT),
+                                                                       gtk_css_number_value_new (0, GTK_CSS_PERCENT)));
 
   gtk_css_style_property_register        ("border-top-color",
                                           GTK_CSS_PROPERTY_BORDER_TOP_COLOR,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BORDER,
                                           color_parse,
-                                          _gtk_css_color_value_new_current_color ());
+                                          gtk_css_color_value_new_current_color ());
   gtk_css_style_property_register        ("border-right-color",
                                           GTK_CSS_PROPERTY_BORDER_RIGHT_COLOR,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BORDER,
                                           color_parse,
-                                          _gtk_css_color_value_new_current_color ());
+                                          gtk_css_color_value_new_current_color ());
   gtk_css_style_property_register        ("border-bottom-color",
                                           GTK_CSS_PROPERTY_BORDER_BOTTOM_COLOR,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BORDER,
                                           color_parse,
-                                          _gtk_css_color_value_new_current_color ());
+                                          gtk_css_color_value_new_current_color ());
   gtk_css_style_property_register        ("border-left-color",
                                           GTK_CSS_PROPERTY_BORDER_LEFT_COLOR,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_BORDER,
                                           color_parse,
-                                          _gtk_css_color_value_new_current_color ());
+                                          gtk_css_color_value_new_current_color ());
   gtk_css_style_property_register        ("outline-color",
                                           GTK_CSS_PROPERTY_OUTLINE_COLOR,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_OUTLINE,
                                           color_parse,
-                                          _gtk_css_color_value_new_current_color ());
+                                          gtk_css_color_value_new_current_color ());
 
   gtk_css_style_property_register        ("background-repeat",
                                           GTK_CSS_PROPERTY_BACKGROUND_REPEAT,
@@ -1234,19 +1234,19 @@ _gtk_css_style_property_init_properties (void)
                                           0,
                                           GTK_CSS_AFFECTS_BORDER,
                                           border_image_slice_parse,
-                                          _gtk_css_border_value_new (_gtk_css_number_value_new (100, GTK_CSS_PERCENT),
-                                                                     _gtk_css_number_value_new (100, GTK_CSS_PERCENT),
-                                                                     _gtk_css_number_value_new (100, GTK_CSS_PERCENT),
-                                                                     _gtk_css_number_value_new (100, GTK_CSS_PERCENT)));
+                                          _gtk_css_border_value_new (gtk_css_number_value_new (100, GTK_CSS_PERCENT),
+                                                                     gtk_css_number_value_new (100, GTK_CSS_PERCENT),
+                                                                     gtk_css_number_value_new (100, GTK_CSS_PERCENT),
+                                                                     gtk_css_number_value_new (100, GTK_CSS_PERCENT)));
   gtk_css_style_property_register        ("border-image-width",
                                           GTK_CSS_PROPERTY_BORDER_IMAGE_WIDTH,
                                           0,
                                           GTK_CSS_AFFECTS_BORDER,
                                           border_image_width_parse,
-                                          _gtk_css_border_value_new (_gtk_css_number_value_new (1, GTK_CSS_NUMBER),
-                                                                     _gtk_css_number_value_new (1, GTK_CSS_NUMBER),
-                                                                     _gtk_css_number_value_new (1, GTK_CSS_NUMBER),
-                                                                     _gtk_css_number_value_new (1, GTK_CSS_NUMBER)));
+                                          _gtk_css_border_value_new (gtk_css_number_value_new (1, GTK_CSS_NUMBER),
+                                                                     gtk_css_number_value_new (1, GTK_CSS_NUMBER),
+                                                                     gtk_css_number_value_new (1, GTK_CSS_NUMBER),
+                                                                     gtk_css_number_value_new (1, GTK_CSS_NUMBER)));
 
   gtk_css_style_property_register        ("-gtk-icon-source",
                                           GTK_CSS_PROPERTY_ICON_SOURCE,
@@ -1259,7 +1259,7 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_INHERIT | GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE | GTK_CSS_AFFECTS_ICON_SIZE,
                                           icon_size_parse,
-                                          _gtk_css_number_value_new (16, GTK_CSS_PX));
+                                          gtk_css_number_value_new (16, GTK_CSS_PX));
   gtk_css_style_property_register        ("-gtk-icon-shadow",
                                           GTK_CSS_PROPERTY_ICON_SHADOW,
                                           GTK_STYLE_PROPERTY_INHERIT | GTK_STYLE_PROPERTY_ANIMATED,
@@ -1289,8 +1289,8 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE,
                                           border_spacing_value_parse,
-                                          _gtk_css_position_value_new (_gtk_css_number_value_new (0, GTK_CSS_PX),
-                                                                       _gtk_css_number_value_new (0, GTK_CSS_PX)));
+                                          _gtk_css_position_value_new (gtk_css_number_value_new (0, GTK_CSS_PX),
+                                                                       gtk_css_number_value_new (0, GTK_CSS_PX)));
 
   gtk_css_style_property_register        ("transform",
                                           GTK_CSS_PROPERTY_TRANSFORM,
@@ -1303,20 +1303,20 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_TRANSFORM,
                                           transform_origin_parse,
-                                          _gtk_css_position_value_new (_gtk_css_number_value_new (50, GTK_CSS_PERCENT),
-                                                                       _gtk_css_number_value_new (50, GTK_CSS_PERCENT)));
+                                          _gtk_css_position_value_new (gtk_css_number_value_new (50, GTK_CSS_PERCENT),
+                                                                       gtk_css_number_value_new (50, GTK_CSS_PERCENT)));
   gtk_css_style_property_register        ("min-width",
                                           GTK_CSS_PROPERTY_MIN_WIDTH,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE,
                                           minmax_parse,
-                                          _gtk_css_number_value_new (0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0, GTK_CSS_PX));
   gtk_css_style_property_register        ("min-height",
                                           GTK_CSS_PROPERTY_MIN_HEIGHT,
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_SIZE,
                                           minmax_parse,
-                                          _gtk_css_number_value_new (0, GTK_CSS_PX));
+                                          gtk_css_number_value_new (0, GTK_CSS_PX));
 
   gtk_css_style_property_register        ("transition-property",
                                           GTK_CSS_PROPERTY_TRANSITION_PROPERTY,
@@ -1329,7 +1329,7 @@ _gtk_css_style_property_init_properties (void)
                                           0,
                                           0,
                                           transition_time_parse,
-                                          _gtk_css_number_value_new (0, GTK_CSS_S));
+                                          gtk_css_number_value_new (0, GTK_CSS_S));
   gtk_css_style_property_register        ("transition-timing-function",
                                           GTK_CSS_PROPERTY_TRANSITION_TIMING_FUNCTION,
                                           0,
@@ -1341,7 +1341,7 @@ _gtk_css_style_property_init_properties (void)
                                           0,
                                           0,
                                           transition_time_parse,
-                                          _gtk_css_number_value_new (0, GTK_CSS_S));
+                                          gtk_css_number_value_new (0, GTK_CSS_S));
 
   gtk_css_style_property_register        ("animation-name",
                                           GTK_CSS_PROPERTY_ANIMATION_NAME,
@@ -1354,7 +1354,7 @@ _gtk_css_style_property_init_properties (void)
                                           0,
                                           0,
                                           transition_time_parse,
-                                          _gtk_css_number_value_new (0, GTK_CSS_S));
+                                          gtk_css_number_value_new (0, GTK_CSS_S));
   gtk_css_style_property_register        ("animation-timing-function",
                                           GTK_CSS_PROPERTY_ANIMATION_TIMING_FUNCTION,
                                           0,
@@ -1366,7 +1366,7 @@ _gtk_css_style_property_init_properties (void)
                                           0,
                                           0,
                                           iteration_count_parse,
-                                          _gtk_css_number_value_new (1, GTK_CSS_NUMBER));
+                                          gtk_css_number_value_new (1, GTK_CSS_NUMBER));
   gtk_css_style_property_register        ("animation-direction",
                                           GTK_CSS_PROPERTY_ANIMATION_DIRECTION,
                                           0,
@@ -1384,7 +1384,7 @@ _gtk_css_style_property_init_properties (void)
                                           0,
                                           0,
                                           transition_time_parse,
-                                          _gtk_css_number_value_new (0, GTK_CSS_S));
+                                          gtk_css_number_value_new (0, GTK_CSS_S));
   gtk_css_style_property_register        ("animation-fill-mode",
                                           GTK_CSS_PROPERTY_ANIMATION_FILL_MODE,
                                           0,
@@ -1397,7 +1397,7 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_POSTEFFECT,
                                           opacity_parse,
-                                          _gtk_css_number_value_new (1, GTK_CSS_NUMBER));
+                                          gtk_css_number_value_new (1, GTK_CSS_NUMBER));
   gtk_css_style_property_register        ("filter",
                                           GTK_CSS_PROPERTY_FILTER,
                                           GTK_STYLE_PROPERTY_ANIMATED,
@@ -1410,13 +1410,13 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_INHERIT | GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_CONTENT,
                                           color_parse,
-                                          _gtk_css_color_value_new_current_color ());
+                                          gtk_css_color_value_new_current_color ());
   gtk_css_style_property_register        ("-gtk-secondary-caret-color",
                                           GTK_CSS_PROPERTY_SECONDARY_CARET_COLOR,
                                           GTK_STYLE_PROPERTY_INHERIT | GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_CONTENT,
                                           color_parse,
-                                          _gtk_css_color_value_new_current_color ());
+                                          gtk_css_color_value_new_current_color ());
   gtk_css_style_property_register        ("font-feature-settings",
                                           GTK_CSS_PROPERTY_FONT_FEATURE_SETTINGS,
                                           GTK_STYLE_PROPERTY_INHERIT | GTK_STYLE_PROPERTY_ANIMATED,
@@ -1434,5 +1434,5 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_STYLE_PROPERTY_INHERIT | GTK_STYLE_PROPERTY_ANIMATED,
                                           GTK_CSS_AFFECTS_TEXT_ATTRS | GTK_CSS_AFFECTS_TEXT_SIZE,
                                           parse_line_height,
-                                          _gtk_css_value_ref (gtk_css_line_height_value_get_default ()));
+                                          gtk_css_value_ref (gtk_css_line_height_value_get_default ()));
 }
