@@ -90,33 +90,33 @@ gtk_css_transform_clear (GtkCssTransform *transform)
     case GTK_CSS_TRANSFORM_MATRIX:
       break;
     case GTK_CSS_TRANSFORM_TRANSLATE:
-      _gtk_css_value_unref (transform->translate.x);
-      _gtk_css_value_unref (transform->translate.y);
-      _gtk_css_value_unref (transform->translate.z);
+      gtk_css_value_unref (transform->translate.x);
+      gtk_css_value_unref (transform->translate.y);
+      gtk_css_value_unref (transform->translate.z);
       break;
     case GTK_CSS_TRANSFORM_ROTATE:
-      _gtk_css_value_unref (transform->rotate.x);
-      _gtk_css_value_unref (transform->rotate.y);
-      _gtk_css_value_unref (transform->rotate.z);
-      _gtk_css_value_unref (transform->rotate.angle);
+      gtk_css_value_unref (transform->rotate.x);
+      gtk_css_value_unref (transform->rotate.y);
+      gtk_css_value_unref (transform->rotate.z);
+      gtk_css_value_unref (transform->rotate.angle);
       break;
     case GTK_CSS_TRANSFORM_SCALE:
-      _gtk_css_value_unref (transform->scale.x);
-      _gtk_css_value_unref (transform->scale.y);
-      _gtk_css_value_unref (transform->scale.z);
+      gtk_css_value_unref (transform->scale.x);
+      gtk_css_value_unref (transform->scale.y);
+      gtk_css_value_unref (transform->scale.z);
       break;
     case GTK_CSS_TRANSFORM_SKEW:
-      _gtk_css_value_unref (transform->skew.x);
-      _gtk_css_value_unref (transform->skew.y);
+      gtk_css_value_unref (transform->skew.x);
+      gtk_css_value_unref (transform->skew.y);
       break;
     case GTK_CSS_TRANSFORM_SKEW_X:
-      _gtk_css_value_unref (transform->skew_x.skew);
+      gtk_css_value_unref (transform->skew_x.skew);
       break;
     case GTK_CSS_TRANSFORM_SKEW_Y:
-      _gtk_css_value_unref (transform->skew_y.skew);
+      gtk_css_value_unref (transform->skew_y.skew);
       break;
     case GTK_CSS_TRANSFORM_PERSPECTIVE:
-      _gtk_css_value_unref (transform->perspective.depth);
+      gtk_css_value_unref (transform->perspective.depth);
       break;
     case GTK_CSS_TRANSFORM_NONE:
     default:
@@ -135,30 +135,30 @@ gtk_css_transform_init_identity (GtkCssTransform     *transform,
       graphene_matrix_init_identity (&transform->matrix.matrix);
       break;
     case GTK_CSS_TRANSFORM_TRANSLATE:
-      transform->translate.x = _gtk_css_number_value_new (0, GTK_CSS_PX);
-      transform->translate.y = _gtk_css_number_value_new (0, GTK_CSS_PX);
-      transform->translate.z = _gtk_css_number_value_new (0, GTK_CSS_PX);
+      transform->translate.x = gtk_css_number_value_new (0, GTK_CSS_PX);
+      transform->translate.y = gtk_css_number_value_new (0, GTK_CSS_PX);
+      transform->translate.z = gtk_css_number_value_new (0, GTK_CSS_PX);
       break;
     case GTK_CSS_TRANSFORM_ROTATE:
-      transform->rotate.x = _gtk_css_number_value_new (0, GTK_CSS_NUMBER);
-      transform->rotate.y = _gtk_css_number_value_new (0, GTK_CSS_NUMBER);
-      transform->rotate.z = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
-      transform->rotate.angle = _gtk_css_number_value_new (0, GTK_CSS_DEG);
+      transform->rotate.x = gtk_css_number_value_new (0, GTK_CSS_NUMBER);
+      transform->rotate.y = gtk_css_number_value_new (0, GTK_CSS_NUMBER);
+      transform->rotate.z = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+      transform->rotate.angle = gtk_css_number_value_new (0, GTK_CSS_DEG);
       break;
     case GTK_CSS_TRANSFORM_SCALE:
-      transform->scale.x = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
-      transform->scale.y = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
-      transform->scale.z = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+      transform->scale.x = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+      transform->scale.y = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+      transform->scale.z = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
       break;
     case GTK_CSS_TRANSFORM_SKEW:
-      transform->skew.x = _gtk_css_number_value_new (0, GTK_CSS_DEG);
-      transform->skew.y = _gtk_css_number_value_new (0, GTK_CSS_DEG);
+      transform->skew.x = gtk_css_number_value_new (0, GTK_CSS_DEG);
+      transform->skew.y = gtk_css_number_value_new (0, GTK_CSS_DEG);
       break;
     case GTK_CSS_TRANSFORM_SKEW_X:
-      transform->skew_x.skew = _gtk_css_number_value_new (0, GTK_CSS_DEG);
+      transform->skew_x.skew = gtk_css_number_value_new (0, GTK_CSS_DEG);
       break;
     case GTK_CSS_TRANSFORM_SKEW_Y:
-      transform->skew_y.skew = _gtk_css_number_value_new (0, GTK_CSS_DEG);
+      transform->skew_y.skew = gtk_css_number_value_new (0, GTK_CSS_DEG);
       break;
     case GTK_CSS_TRANSFORM_PERSPECTIVE:
       return FALSE;
@@ -188,9 +188,9 @@ gtk_css_transform_apply (const GtkCssTransform   *transform,
     case GTK_CSS_TRANSFORM_TRANSLATE:
       return gsk_transform_translate_3d (next,
                                          &GRAPHENE_POINT3D_INIT (
-                                             _gtk_css_number_value_get (transform->translate.x, 100),
-                                             _gtk_css_number_value_get (transform->translate.y, 100),
-                                              _gtk_css_number_value_get (transform->translate.z, 100)
+                                             gtk_css_number_value_get (transform->translate.x, 100),
+                                             gtk_css_number_value_get (transform->translate.y, 100),
+                                             gtk_css_number_value_get (transform->translate.z, 100)
                                          ));
 
     case GTK_CSS_TRANSFORM_ROTATE:
@@ -198,41 +198,41 @@ gtk_css_transform_apply (const GtkCssTransform   *transform,
         graphene_vec3_t axis;
 
         graphene_vec3_init (&axis,
-                            _gtk_css_number_value_get (transform->rotate.x, 1),
-                            _gtk_css_number_value_get (transform->rotate.y, 1),
-                            _gtk_css_number_value_get (transform->rotate.z, 1));
+                            gtk_css_number_value_get (transform->rotate.x, 1),
+                            gtk_css_number_value_get (transform->rotate.y, 1),
+                            gtk_css_number_value_get (transform->rotate.z, 1));
         return gsk_transform_rotate_3d (next,
-                                        _gtk_css_number_value_get (transform->rotate.angle, 100),
+                                        gtk_css_number_value_get (transform->rotate.angle, 100),
                                         &axis);
       }
 
     case GTK_CSS_TRANSFORM_SCALE:
       return gsk_transform_scale_3d (next,
-                                     _gtk_css_number_value_get (transform->scale.x, 1),
-                                     _gtk_css_number_value_get (transform->scale.y, 1),
-                                     _gtk_css_number_value_get (transform->scale.z, 1));
+                                     gtk_css_number_value_get (transform->scale.x, 1),
+                                     gtk_css_number_value_get (transform->scale.y, 1),
+                                     gtk_css_number_value_get (transform->scale.z, 1));
 
     case GTK_CSS_TRANSFORM_SKEW:
       graphene_matrix_init_skew (&skew,
-                                 _gtk_css_number_value_get (transform->skew.x, 100) / 180.0f * G_PI,
-                                 _gtk_css_number_value_get (transform->skew.y, 100) / 180.0f * G_PI);
+                                 gtk_css_number_value_get (transform->skew.x, 100) / 180.0f * G_PI,
+                                 gtk_css_number_value_get (transform->skew.y, 100) / 180.0f * G_PI);
       return gsk_transform_matrix (next, &skew);
 
     case GTK_CSS_TRANSFORM_SKEW_X:
       graphene_matrix_init_skew (&skew,
-                                 _gtk_css_number_value_get (transform->skew_x.skew, 100) / 180.0f * G_PI,
+                                 gtk_css_number_value_get (transform->skew_x.skew, 100) / 180.0f * G_PI,
                                  0);
       return gsk_transform_matrix (next, &skew);
 
     case GTK_CSS_TRANSFORM_SKEW_Y:
       graphene_matrix_init_skew (&skew,
                                  0,
-                                 _gtk_css_number_value_get (transform->skew_y.skew, 100) / 180.0f * G_PI);
+                                 gtk_css_number_value_get (transform->skew_y.skew, 100) / 180.0f * G_PI);
       return gsk_transform_matrix (next, &skew);
 
     case GTK_CSS_TRANSFORM_PERSPECTIVE:
       return gsk_transform_perspective (next,
-                                        _gtk_css_number_value_get (transform->perspective.depth, 100));
+                                        gtk_css_number_value_get (transform->perspective.depth, 100));
 
     case GTK_CSS_TRANSFORM_NONE:
     default:
@@ -273,12 +273,10 @@ gtk_css_value_transform_free (GtkCssValue *value)
 
 /* returns TRUE if dest == src */
 static gboolean
-gtk_css_transform_compute (GtkCssTransform  *dest,
-                           GtkCssTransform  *src,
-                           guint             property_id,
-                           GtkStyleProvider *provider,
-                           GtkCssStyle      *style,
-                           GtkCssStyle      *parent_style)
+gtk_css_transform_compute (GtkCssTransform      *dest,
+                           GtkCssTransform      *src,
+                           guint                 property_id,
+                           GtkCssComputeContext *context)
 {
   dest->type = src->type;
 
@@ -288,41 +286,41 @@ gtk_css_transform_compute (GtkCssTransform  *dest,
       memcpy (dest, src, sizeof (GtkCssTransform));
       return TRUE;
     case GTK_CSS_TRANSFORM_TRANSLATE:
-      dest->translate.x = _gtk_css_value_compute (src->translate.x, property_id, provider, style, parent_style);
-      dest->translate.y = _gtk_css_value_compute (src->translate.y, property_id, provider, style, parent_style);
-      dest->translate.z = _gtk_css_value_compute (src->translate.z, property_id, provider, style, parent_style);
+      dest->translate.x = gtk_css_value_compute (src->translate.x, property_id, context);
+      dest->translate.y = gtk_css_value_compute (src->translate.y, property_id, context);
+      dest->translate.z = gtk_css_value_compute (src->translate.z, property_id, context);
       return dest->translate.x == src->translate.x
           && dest->translate.y == src->translate.y
           && dest->translate.z == src->translate.z;
     case GTK_CSS_TRANSFORM_ROTATE:
-      dest->rotate.x = _gtk_css_value_compute (src->rotate.x, property_id, provider, style, parent_style);
-      dest->rotate.y = _gtk_css_value_compute (src->rotate.y, property_id, provider, style, parent_style);
-      dest->rotate.z = _gtk_css_value_compute (src->rotate.z, property_id, provider, style, parent_style);
-      dest->rotate.angle = _gtk_css_value_compute (src->rotate.angle, property_id, provider, style, parent_style);
+      dest->rotate.x = gtk_css_value_compute (src->rotate.x, property_id, context);
+      dest->rotate.y = gtk_css_value_compute (src->rotate.y, property_id, context);
+      dest->rotate.z = gtk_css_value_compute (src->rotate.z, property_id, context);
+      dest->rotate.angle = gtk_css_value_compute (src->rotate.angle, property_id, context);
       return dest->rotate.x == src->rotate.x
           && dest->rotate.y == src->rotate.y
           && dest->rotate.z == src->rotate.z
           && dest->rotate.angle == src->rotate.angle;
     case GTK_CSS_TRANSFORM_SCALE:
-      dest->scale.x = _gtk_css_value_compute (src->scale.x, property_id, provider, style, parent_style);
-      dest->scale.y = _gtk_css_value_compute (src->scale.y, property_id, provider, style, parent_style);
-      dest->scale.z = _gtk_css_value_compute (src->scale.z, property_id, provider, style, parent_style);
+      dest->scale.x = gtk_css_value_compute (src->scale.x, property_id, context);
+      dest->scale.y = gtk_css_value_compute (src->scale.y, property_id, context);
+      dest->scale.z = gtk_css_value_compute (src->scale.z, property_id, context);
       return dest->scale.x == src->scale.x
           && dest->scale.y == src->scale.y
           && dest->scale.z == src->scale.z;
     case GTK_CSS_TRANSFORM_SKEW:
-      dest->skew.x = _gtk_css_value_compute (src->skew.x, property_id, provider, style, parent_style);
-      dest->skew.y = _gtk_css_value_compute (src->skew.y, property_id, provider, style, parent_style);
+      dest->skew.x = gtk_css_value_compute (src->skew.x, property_id, context);
+      dest->skew.y = gtk_css_value_compute (src->skew.y, property_id, context);
       return dest->skew.x == src->skew.x
           && dest->skew.y == src->skew.y;
     case GTK_CSS_TRANSFORM_SKEW_X:
-      dest->skew_x.skew = _gtk_css_value_compute (src->skew_x.skew, property_id, provider, style, parent_style);
+      dest->skew_x.skew = gtk_css_value_compute (src->skew_x.skew, property_id, context);
       return dest->skew_x.skew == src->skew_x.skew;
     case GTK_CSS_TRANSFORM_SKEW_Y:
-      dest->skew_y.skew = _gtk_css_value_compute (src->skew_y.skew, property_id, provider, style, parent_style);
+      dest->skew_y.skew = gtk_css_value_compute (src->skew_y.skew, property_id, context);
       return dest->skew_y.skew == src->skew_y.skew;
     case GTK_CSS_TRANSFORM_PERSPECTIVE:
-      dest->perspective.depth = _gtk_css_value_compute (src->perspective.depth, property_id, provider, style, parent_style);
+      dest->perspective.depth = gtk_css_value_compute (src->perspective.depth, property_id, context);
       return dest->perspective.depth == src->perspective.depth;
     case GTK_CSS_TRANSFORM_NONE:
     default:
@@ -332,11 +330,9 @@ gtk_css_transform_compute (GtkCssTransform  *dest,
 }
 
 static GtkCssValue *
-gtk_css_value_transform_compute (GtkCssValue      *value,
-                                 guint             property_id,
-                                 GtkStyleProvider *provider,
-                                 GtkCssStyle      *style,
-                                 GtkCssStyle      *parent_style)
+gtk_css_value_transform_compute (GtkCssValue          *value,
+                                 guint                 property_id,
+                                 GtkCssComputeContext *context)
 {
   GtkCssValue *result;
   gboolean changes;
@@ -344,7 +340,7 @@ gtk_css_value_transform_compute (GtkCssValue      *value,
 
   /* Special case the 99% case of "none" */
   if (gtk_css_transform_value_is_none (value))
-    return _gtk_css_value_ref (value);
+    return gtk_css_value_ref (value);
 
   changes = FALSE;
   result = gtk_css_transform_value_alloc (value->n_transforms);
@@ -354,15 +350,13 @@ gtk_css_value_transform_compute (GtkCssValue      *value,
       changes |= !gtk_css_transform_compute (&result->transforms[i],
                                              &value->transforms[i],
                                              property_id,
-                                             provider,
-                                             style,
-                                             parent_style);
+                                             context);
     }
 
   if (!changes)
     {
-      _gtk_css_value_unref (result);
-      result = _gtk_css_value_ref (value);
+      gtk_css_value_unref (result);
+      result = gtk_css_value_ref (value);
     }
 
   return result;
@@ -391,27 +385,27 @@ gtk_css_transform_equal (const GtkCssTransform *transform1,
         return TRUE;
       }
     case GTK_CSS_TRANSFORM_TRANSLATE:
-      return _gtk_css_value_equal (transform1->translate.x, transform2->translate.x)
-          && _gtk_css_value_equal (transform1->translate.y, transform2->translate.y)
-          && _gtk_css_value_equal (transform1->translate.z, transform2->translate.z);
+      return gtk_css_value_equal (transform1->translate.x, transform2->translate.x)
+          && gtk_css_value_equal (transform1->translate.y, transform2->translate.y)
+          && gtk_css_value_equal (transform1->translate.z, transform2->translate.z);
     case GTK_CSS_TRANSFORM_ROTATE:
-      return _gtk_css_value_equal (transform1->rotate.x, transform2->rotate.x)
-          && _gtk_css_value_equal (transform1->rotate.y, transform2->rotate.y)
-          && _gtk_css_value_equal (transform1->rotate.z, transform2->rotate.z)
-          && _gtk_css_value_equal (transform1->rotate.angle, transform2->rotate.angle);
+      return gtk_css_value_equal (transform1->rotate.x, transform2->rotate.x)
+          && gtk_css_value_equal (transform1->rotate.y, transform2->rotate.y)
+          && gtk_css_value_equal (transform1->rotate.z, transform2->rotate.z)
+          && gtk_css_value_equal (transform1->rotate.angle, transform2->rotate.angle);
     case GTK_CSS_TRANSFORM_SCALE:
-      return _gtk_css_value_equal (transform1->scale.x, transform2->scale.x)
-          && _gtk_css_value_equal (transform1->scale.y, transform2->scale.y)
-          && _gtk_css_value_equal (transform1->scale.z, transform2->scale.z);
+      return gtk_css_value_equal (transform1->scale.x, transform2->scale.x)
+          && gtk_css_value_equal (transform1->scale.y, transform2->scale.y)
+          && gtk_css_value_equal (transform1->scale.z, transform2->scale.z);
     case GTK_CSS_TRANSFORM_SKEW:
-      return _gtk_css_value_equal (transform1->skew.x, transform2->skew.x)
-          && _gtk_css_value_equal (transform1->skew.y, transform2->skew.y);
+      return gtk_css_value_equal (transform1->skew.x, transform2->skew.x)
+          && gtk_css_value_equal (transform1->skew.y, transform2->skew.y);
     case GTK_CSS_TRANSFORM_SKEW_X:
-      return _gtk_css_value_equal (transform1->skew_x.skew, transform2->skew_x.skew);
+      return gtk_css_value_equal (transform1->skew_x.skew, transform2->skew_x.skew);
     case GTK_CSS_TRANSFORM_SKEW_Y:
-      return _gtk_css_value_equal (transform1->skew_y.skew, transform2->skew_y.skew);
+      return gtk_css_value_equal (transform1->skew_y.skew, transform2->skew_y.skew);
     case GTK_CSS_TRANSFORM_PERSPECTIVE:
-      return _gtk_css_value_equal (transform1->perspective.depth, transform2->perspective.depth);
+      return gtk_css_value_equal (transform1->perspective.depth, transform2->perspective.depth);
     case GTK_CSS_TRANSFORM_NONE:
     default:
       g_assert_not_reached ();
@@ -504,30 +498,30 @@ gtk_css_transform_transition (GtkCssTransform       *result,
                                    &result->matrix.matrix);
       break;
     case GTK_CSS_TRANSFORM_TRANSLATE:
-      result->translate.x = _gtk_css_value_transition (start->translate.x, end->translate.x, property_id, progress);
-      result->translate.y = _gtk_css_value_transition (start->translate.y, end->translate.y, property_id, progress);
-      result->translate.z = _gtk_css_value_transition (start->translate.z, end->translate.z, property_id, progress);
+      result->translate.x = gtk_css_value_transition (start->translate.x, end->translate.x, property_id, progress);
+      result->translate.y = gtk_css_value_transition (start->translate.y, end->translate.y, property_id, progress);
+      result->translate.z = gtk_css_value_transition (start->translate.z, end->translate.z, property_id, progress);
       break;
     case GTK_CSS_TRANSFORM_ROTATE:
-      result->rotate.x = _gtk_css_value_transition (start->rotate.x, end->rotate.x, property_id, progress);
-      result->rotate.y = _gtk_css_value_transition (start->rotate.y, end->rotate.y, property_id, progress);
-      result->rotate.z = _gtk_css_value_transition (start->rotate.z, end->rotate.z, property_id, progress);
-      result->rotate.angle = _gtk_css_value_transition (start->rotate.angle, end->rotate.angle, property_id, progress);
+      result->rotate.x = gtk_css_value_transition (start->rotate.x, end->rotate.x, property_id, progress);
+      result->rotate.y = gtk_css_value_transition (start->rotate.y, end->rotate.y, property_id, progress);
+      result->rotate.z = gtk_css_value_transition (start->rotate.z, end->rotate.z, property_id, progress);
+      result->rotate.angle = gtk_css_value_transition (start->rotate.angle, end->rotate.angle, property_id, progress);
       break;
     case GTK_CSS_TRANSFORM_SCALE:
-      result->scale.x = _gtk_css_value_transition (start->scale.x, end->scale.x, property_id, progress);
-      result->scale.y = _gtk_css_value_transition (start->scale.y, end->scale.y, property_id, progress);
-      result->scale.z = _gtk_css_value_transition (start->scale.z, end->scale.z, property_id, progress);
+      result->scale.x = gtk_css_value_transition (start->scale.x, end->scale.x, property_id, progress);
+      result->scale.y = gtk_css_value_transition (start->scale.y, end->scale.y, property_id, progress);
+      result->scale.z = gtk_css_value_transition (start->scale.z, end->scale.z, property_id, progress);
       break;
     case GTK_CSS_TRANSFORM_SKEW:
-      result->skew.x = _gtk_css_value_transition (start->skew.x, end->skew.x, property_id, progress);
-      result->skew.y = _gtk_css_value_transition (start->skew.y, end->skew.y, property_id, progress);
+      result->skew.x = gtk_css_value_transition (start->skew.x, end->skew.x, property_id, progress);
+      result->skew.y = gtk_css_value_transition (start->skew.y, end->skew.y, property_id, progress);
       break;
     case GTK_CSS_TRANSFORM_SKEW_X:
-      result->skew_x.skew = _gtk_css_value_transition (start->skew_x.skew, end->skew_x.skew, property_id, progress);
+      result->skew_x.skew = gtk_css_value_transition (start->skew_x.skew, end->skew_x.skew, property_id, progress);
       break;
     case GTK_CSS_TRANSFORM_SKEW_Y:
-      result->skew_y.skew = _gtk_css_value_transition (start->skew_y.skew, end->skew_y.skew, property_id, progress);
+      result->skew_y.skew = gtk_css_value_transition (start->skew_y.skew, end->skew_y.skew, property_id, progress);
       break;
     case GTK_CSS_TRANSFORM_PERSPECTIVE:
       gtk_css_transform_transition_default (result, start, end, property_id, progress);
@@ -551,7 +545,7 @@ gtk_css_value_transform_transition (GtkCssValue *start,
   if (gtk_css_transform_value_is_none (start))
     {
       if (gtk_css_transform_value_is_none (end))
-        return _gtk_css_value_ref (start);
+        return gtk_css_value_ref (start);
 
       n = 0;
     }
@@ -699,67 +693,67 @@ gtk_css_transform_print (const GtkCssTransform *transform,
       break;
     case GTK_CSS_TRANSFORM_TRANSLATE:
       g_string_append (string, "translate3d(");
-      _gtk_css_value_print (transform->translate.x, string);
+      gtk_css_value_print (transform->translate.x, string);
       g_string_append (string, ", ");
-      _gtk_css_value_print (transform->translate.y, string);
+      gtk_css_value_print (transform->translate.y, string);
       g_string_append (string, ", ");
-      _gtk_css_value_print (transform->translate.z, string);
+      gtk_css_value_print (transform->translate.z, string);
       g_string_append (string, ")");
       break;
     case GTK_CSS_TRANSFORM_ROTATE:
       g_string_append (string, "rotate3d(");
-      _gtk_css_value_print (transform->rotate.x, string);
+      gtk_css_value_print (transform->rotate.x, string);
       g_string_append (string, ", ");
-      _gtk_css_value_print (transform->rotate.y, string);
+      gtk_css_value_print (transform->rotate.y, string);
       g_string_append (string, ", ");
-      _gtk_css_value_print (transform->rotate.z, string);
+      gtk_css_value_print (transform->rotate.z, string);
       g_string_append (string, ", ");
-      _gtk_css_value_print (transform->rotate.angle, string);
+      gtk_css_value_print (transform->rotate.angle, string);
       g_string_append (string, ")");
       break;
     case GTK_CSS_TRANSFORM_SCALE:
-      if (_gtk_css_number_value_get (transform->scale.z, 100) == 1)
+      if (gtk_css_number_value_get (transform->scale.z, 100) == 1)
         {
           g_string_append (string, "scale(");
-          _gtk_css_value_print (transform->scale.x, string);
-          if (!_gtk_css_value_equal (transform->scale.x, transform->scale.y))
+          gtk_css_value_print (transform->scale.x, string);
+          if (!gtk_css_value_equal (transform->scale.x, transform->scale.y))
             {
               g_string_append (string, ", ");
-              _gtk_css_value_print (transform->scale.y, string);
+              gtk_css_value_print (transform->scale.y, string);
             }
           g_string_append (string, ")");
         }
       else
         {
           g_string_append (string, "scale3d(");
-          _gtk_css_value_print (transform->scale.x, string);
+          gtk_css_value_print (transform->scale.x, string);
           g_string_append (string, ", ");
-          _gtk_css_value_print (transform->scale.y, string);
+          gtk_css_value_print (transform->scale.y, string);
           g_string_append (string, ", ");
-          _gtk_css_value_print (transform->scale.z, string);
+          gtk_css_value_print (transform->scale.z, string);
           g_string_append (string, ")");
         }
       break;
     case GTK_CSS_TRANSFORM_SKEW:
       g_string_append (string, "skew(");
-      _gtk_css_value_print (transform->skew.x, string);
+      gtk_css_value_print (transform->skew.x, string);
       g_string_append (string, ", ");
-      _gtk_css_value_print (transform->skew.y, string);
+      gtk_css_value_print (transform->skew.y, string);
       g_string_append (string, ")");
       break;
     case GTK_CSS_TRANSFORM_SKEW_X:
       g_string_append (string, "skewX(");
-      _gtk_css_value_print (transform->skew_x.skew, string);
+      gtk_css_value_print (transform->skew_x.skew, string);
       g_string_append (string, ")");
       break;
     case GTK_CSS_TRANSFORM_SKEW_Y:
       g_string_append (string, "skewY(");
-      _gtk_css_value_print (transform->skew_y.skew, string);
+      gtk_css_value_print (transform->skew_y.skew, string);
       g_string_append (string, ")");
       break;
     case GTK_CSS_TRANSFORM_PERSPECTIVE:
       g_string_append (string, "perspective(");
-      _gtk_css_value_print (transform->perspective.depth, string);
+      gtk_css_value_print (transform->perspective.depth, string);
       g_string_append (string, ")");
       break;
     case GTK_CSS_TRANSFORM_NONE:
@@ -794,6 +788,7 @@ static const GtkCssValueClass GTK_CSS_VALUE_TRANSFORM = {
   "GtkCssTransformValue",
   gtk_css_value_transform_free,
   gtk_css_value_transform_compute,
+  NULL,
   gtk_css_value_transform_equal,
   gtk_css_value_transform_transition,
   NULL,
@@ -801,7 +796,7 @@ static const GtkCssValueClass GTK_CSS_VALUE_TRANSFORM = {
   gtk_css_value_transform_print
 };
 
-static GtkCssValue transform_none_singleton = { &GTK_CSS_VALUE_TRANSFORM, 1, TRUE, 0, {  { GTK_CSS_TRANSFORM_NONE } } };
+static GtkCssValue transform_none_singleton = { &GTK_CSS_VALUE_TRANSFORM, 1, 1, 0, 0, 0, {  { GTK_CSS_TRANSFORM_NONE } } };
 
 static GtkCssValue *
 gtk_css_transform_value_alloc (guint n_transforms)
@@ -810,7 +805,7 @@ gtk_css_transform_value_alloc (guint n_transforms)
            
   g_return_val_if_fail (n_transforms > 0, NULL);
          
-  result = _gtk_css_value_alloc (&GTK_CSS_VALUE_TRANSFORM, sizeof (GtkCssValue) + sizeof (GtkCssTransform) * (n_transforms - 1));
+  result = gtk_css_value_alloc (&GTK_CSS_VALUE_TRANSFORM, sizeof (GtkCssValue) + sizeof (GtkCssTransform) * (n_transforms - 1));
   result->n_transforms = n_transforms;
             
   return result;
@@ -819,7 +814,7 @@ gtk_css_transform_value_alloc (guint n_transforms)
 GtkCssValue *
 _gtk_css_transform_value_new_none (void)
 {
-  return _gtk_css_value_ref (&transform_none_singleton);
+  return gtk_css_value_ref (&transform_none_singleton);
 }
 
 static gboolean
@@ -850,7 +845,7 @@ gtk_css_transform_parse_length (GtkCssParser *parser,
 {
   GtkCssValue **values = data;
 
-  values[n] = _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_LENGTH);
+  values[n] = gtk_css_number_value_parse (parser, GTK_CSS_PARSE_LENGTH);
   if (values[n] == NULL)
     return 0;
 
@@ -864,7 +859,7 @@ gtk_css_transform_parse_angle (GtkCssParser *parser,
 {
   GtkCssValue **values = data;
 
-  values[n] = _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_ANGLE);
+  values[n] = gtk_css_number_value_parse (parser, GTK_CSS_PARSE_ANGLE);
   if (values[n] == NULL)
     return 0;
 
@@ -878,7 +873,7 @@ gtk_css_transform_parse_number (GtkCssParser *parser,
 {
   GtkCssValue **values = data;
 
-  values[n] = _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER);
+  values[n] = gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER);
   if (values[n] == NULL)
     return 0;
 
@@ -895,25 +890,25 @@ gtk_css_transform_parse_rotate3d (GtkCssParser *parser,
   switch (n)
   {
     case 0:
-      transform->rotate.x = _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER);
+      transform->rotate.x = gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER);
       if (transform->rotate.x == NULL)
         return 0;
       break;
 
     case 1:
-      transform->rotate.y = _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER);
+      transform->rotate.y = gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER);
       if (transform->rotate.y == NULL)
         return 0;
       break;
 
     case 2:
-      transform->rotate.z = _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER);
+      transform->rotate.z = gtk_css_number_value_parse (parser, GTK_CSS_PARSE_NUMBER);
       if (transform->rotate.z == NULL)
         return 0;
       break;
 
     case 3:
-      transform->rotate.angle = _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_ANGLE);
+      transform->rotate.angle = gtk_css_number_value_parse (parser, GTK_CSS_PARSE_ANGLE);
       if (transform->rotate.angle == NULL)
         return 0;
       break;
@@ -978,9 +973,9 @@ _gtk_css_transform_value_parse (GtkCssParser *parser)
             goto fail;
 
           transform.type = GTK_CSS_TRANSFORM_ROTATE;
-          transform.rotate.x = _gtk_css_number_value_new (0, GTK_CSS_NUMBER);
-          transform.rotate.y = _gtk_css_number_value_new (0, GTK_CSS_NUMBER);
-          transform.rotate.z = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+          transform.rotate.x = gtk_css_number_value_new (0, GTK_CSS_NUMBER);
+          transform.rotate.y = gtk_css_number_value_new (0, GTK_CSS_NUMBER);
+          transform.rotate.z = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
           computed = computed && gtk_css_value_is_computed (transform.rotate.angle);
         }
       else if (gtk_css_parser_has_function (parser, "rotate3d"))
@@ -1006,9 +1001,9 @@ _gtk_css_transform_value_parse (GtkCssParser *parser)
             goto fail;
 
           transform.type = GTK_CSS_TRANSFORM_ROTATE;
-          transform.rotate.x = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
-          transform.rotate.y = _gtk_css_number_value_new (0, GTK_CSS_NUMBER);
-          transform.rotate.z = _gtk_css_number_value_new (0, GTK_CSS_NUMBER);
+          transform.rotate.x = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+          transform.rotate.y = gtk_css_number_value_new (0, GTK_CSS_NUMBER);
+          transform.rotate.z = gtk_css_number_value_new (0, GTK_CSS_NUMBER);
           computed = computed && gtk_css_value_is_computed (transform.rotate.angle);
         }
       else if (gtk_css_parser_has_function (parser, "rotateY"))
@@ -1017,9 +1012,9 @@ _gtk_css_transform_value_parse (GtkCssParser *parser)
             goto fail;
 
           transform.type = GTK_CSS_TRANSFORM_ROTATE;
-          transform.rotate.x = _gtk_css_number_value_new (0, GTK_CSS_NUMBER);
-          transform.rotate.y = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
-          transform.rotate.z = _gtk_css_number_value_new (0, GTK_CSS_NUMBER);
+          transform.rotate.x = gtk_css_number_value_new (0, GTK_CSS_NUMBER);
+          transform.rotate.y = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+          transform.rotate.z = gtk_css_number_value_new (0, GTK_CSS_NUMBER);
           computed = computed && gtk_css_value_is_computed (transform.rotate.angle);
         }
       else if (gtk_css_parser_has_function (parser, "scale"))
@@ -1039,7 +1034,7 @@ _gtk_css_transform_value_parse (GtkCssParser *parser)
             transform.scale.y = values[1];
           else
             transform.scale.y = gtk_css_value_ref (values[0]);
-          transform.scale.z = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+          transform.scale.z = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
           computed = computed && gtk_css_value_is_computed (transform.scale.x) &&
                                  gtk_css_value_is_computed (transform.scale.y);
         }
@@ -1069,8 +1064,8 @@ _gtk_css_transform_value_parse (GtkCssParser *parser)
             goto fail;
 
           transform.type = GTK_CSS_TRANSFORM_SCALE;
-          transform.scale.y = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
-          transform.scale.z = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+          transform.scale.y = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+          transform.scale.z = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
           computed = computed && gtk_css_value_is_computed (transform.scale.x);
         }
       else if (gtk_css_parser_has_function (parser, "scaleY"))
@@ -1079,8 +1074,8 @@ _gtk_css_transform_value_parse (GtkCssParser *parser)
             goto fail;
 
           transform.type = GTK_CSS_TRANSFORM_SCALE;
-          transform.scale.x = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
-          transform.scale.z = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+          transform.scale.x = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+          transform.scale.z = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
           computed = computed && gtk_css_value_is_computed (transform.scale.y);
         }
       else if (gtk_css_parser_has_function (parser, "scaleZ"))
@@ -1089,8 +1084,8 @@ _gtk_css_transform_value_parse (GtkCssParser *parser)
             goto fail;
 
           transform.type = GTK_CSS_TRANSFORM_SCALE;
-          transform.scale.x = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
-          transform.scale.y = _gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+          transform.scale.x = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
+          transform.scale.y = gtk_css_number_value_new (1, GTK_CSS_NUMBER);
           computed = computed && gtk_css_value_is_computed (transform.scale.z);
         }
       else if (gtk_css_parser_has_function (parser, "skew"))
@@ -1142,8 +1137,8 @@ _gtk_css_transform_value_parse (GtkCssParser *parser)
           if (values[1])
             transform.translate.y = values[1];
           else
-            transform.translate.y = _gtk_css_number_value_new (0, GTK_CSS_PX);
-          transform.translate.z = _gtk_css_number_value_new (0, GTK_CSS_PX);
+            transform.translate.y = gtk_css_number_value_new (0, GTK_CSS_PX);
+          transform.translate.z = gtk_css_number_value_new (0, GTK_CSS_PX);
           computed = computed && gtk_css_value_is_computed (transform.translate.x) &&
                                  gtk_css_value_is_computed (transform.translate.y);
         }
@@ -1173,8 +1168,8 @@ _gtk_css_transform_value_parse (GtkCssParser *parser)
             goto fail;
 
           transform.type = GTK_CSS_TRANSFORM_TRANSLATE;
-          transform.translate.y = _gtk_css_number_value_new (0, GTK_CSS_PX);
-          transform.translate.z = _gtk_css_number_value_new (0, GTK_CSS_PX);
+          transform.translate.y = gtk_css_number_value_new (0, GTK_CSS_PX);
+          transform.translate.z = gtk_css_number_value_new (0, GTK_CSS_PX);
           computed = computed && gtk_css_value_is_computed (transform.translate.x);
         }
       else if (gtk_css_parser_has_function (parser, "translateY"))
@@ -1183,8 +1178,8 @@ _gtk_css_transform_value_parse (GtkCssParser *parser)
             goto fail;
 
           transform.type = GTK_CSS_TRANSFORM_TRANSLATE;
-          transform.translate.x = _gtk_css_number_value_new (0, GTK_CSS_PX);
-          transform.translate.z = _gtk_css_number_value_new (0, GTK_CSS_PX);
+          transform.translate.x = gtk_css_number_value_new (0, GTK_CSS_PX);
+          transform.translate.z = gtk_css_number_value_new (0, GTK_CSS_PX);
           computed = computed && gtk_css_value_is_computed (transform.translate.y);
         }
       else if (gtk_css_parser_has_function (parser, "translateZ"))
@@ -1193,8 +1188,8 @@ _gtk_css_transform_value_parse (GtkCssParser *parser)
             goto fail;
 
           transform.type = GTK_CSS_TRANSFORM_TRANSLATE;
-          transform.translate.x = _gtk_css_number_value_new (0, GTK_CSS_PX);
-          transform.translate.y = _gtk_css_number_value_new (0, GTK_CSS_PX);
+          transform.translate.x = gtk_css_number_value_new (0, GTK_CSS_PX);
+          transform.translate.y = gtk_css_number_value_new (0, GTK_CSS_PX);
           computed = computed && gtk_css_value_is_computed (transform.translate.z);
         }
       else
