@@ -21,8 +21,7 @@
 /**
  * GtkGestureSingle:
  *
- * `GtkGestureSingle` is a `GtkGestures` subclass optimized for singe-touch
- * and mouse gestures.
+ * A `GtkGesture` subclass optimized for singe-touch and mouse gestures.
  *
  * Under interaction, these gestures stick to the first interacting sequence,
  * which is accessible through [method@Gtk.GestureSingle.get_current_sequence]
@@ -139,7 +138,7 @@ gtk_gesture_single_handle_event (GtkEventController *controller,
   GdkDevice *source_device;
   GdkInputSource source;
   guint button = 0, state, i;
-  gboolean retval, test_touchscreen = FALSE;
+  gboolean retval;
   GdkEventType event_type;
 
   source_device = gdk_event_get_device (event);
@@ -150,9 +149,6 @@ gtk_gesture_single_handle_event (GtkEventController *controller,
   priv = gtk_gesture_single_get_instance_private (GTK_GESTURE_SINGLE (controller));
   source = gdk_device_get_source (source_device);
 
-  if (source != GDK_SOURCE_TOUCHSCREEN)
-    test_touchscreen = gtk_simulate_touchscreen ();
-
   event_type = gdk_event_get_event_type (event);
 
   switch ((guint) event_type)
@@ -168,7 +164,7 @@ gtk_gesture_single_handle_event (GtkEventController *controller,
       break;
     case GDK_BUTTON_PRESS:
     case GDK_BUTTON_RELEASE:
-      if (priv->touch_only && !test_touchscreen && source != GDK_SOURCE_TOUCHSCREEN)
+      if (priv->touch_only && source != GDK_SOURCE_TOUCHSCREEN)
         return FALSE;
 
       button = gdk_button_event_get_button (event);
@@ -176,7 +172,7 @@ gtk_gesture_single_handle_event (GtkEventController *controller,
     case GDK_MOTION_NOTIFY:
       if (!gtk_gesture_handles_sequence (GTK_GESTURE (controller), sequence))
         return FALSE;
-      if (priv->touch_only && !test_touchscreen && source != GDK_SOURCE_TOUCHSCREEN)
+      if (priv->touch_only && source != GDK_SOURCE_TOUCHSCREEN)
         return FALSE;
       state = gdk_event_get_modifier_state (event);
 
@@ -259,7 +255,7 @@ gtk_gesture_single_class_init (GtkGestureSingleClass *klass)
   gesture_class->cancel = gtk_gesture_single_cancel;
 
   /**
-   * GtkGestureSingle:touch-only: (attributes org.gtk.Property.get=gtk_gesture_single_get_touch_only org.gtk.Property.set=gtk_gesture_single_set_touch_only)
+   * GtkGestureSingle:touch-only:
    *
    * Whether the gesture handles only touch events.
    */
@@ -269,7 +265,7 @@ gtk_gesture_single_class_init (GtkGestureSingleClass *klass)
                             GTK_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkGestureSingle:exclusive: (attributes org.gtk.Property.get=gtk_gesture_single_get_exclusive org.gtk.Property.set=gtk_gesture_single_set_exclusive)
+   * GtkGestureSingle:exclusive:
    *
    * Whether the gesture is exclusive.
    *
@@ -281,7 +277,7 @@ gtk_gesture_single_class_init (GtkGestureSingleClass *klass)
                             GTK_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkGestureSingle:button: (attributes org.gtk.Property.get=gtk_gesture_single_get_button org.gtk.Property.set=gtk_gesture_single_set_button)
+   * GtkGestureSingle:button:
    *
    * Mouse button number to listen to, or 0 to listen for any button.
    */
@@ -305,7 +301,7 @@ gtk_gesture_single_init (GtkGestureSingle *gesture)
 }
 
 /**
- * gtk_gesture_single_get_touch_only: (attributes org.gtk.Method.get_property=touch-only)
+ * gtk_gesture_single_get_touch_only:
  * @gesture: a `GtkGestureSingle`
  *
  * Returns %TRUE if the gesture is only triggered by touch events.
@@ -325,7 +321,7 @@ gtk_gesture_single_get_touch_only (GtkGestureSingle *gesture)
 }
 
 /**
- * gtk_gesture_single_set_touch_only: (attributes org.gtk.Method.set_property=touch-only)
+ * gtk_gesture_single_set_touch_only:
  * @gesture: a `GtkGestureSingle`
  * @touch_only: whether @gesture handles only touch events
  *
@@ -354,7 +350,7 @@ gtk_gesture_single_set_touch_only (GtkGestureSingle *gesture,
 }
 
 /**
- * gtk_gesture_single_get_exclusive: (attributes org.gtk.Method.get_property=exclusive)
+ * gtk_gesture_single_get_exclusive:
  * @gesture: a `GtkGestureSingle`
  *
  * Gets whether a gesture is exclusive.
@@ -376,7 +372,7 @@ gtk_gesture_single_get_exclusive (GtkGestureSingle *gesture)
 }
 
 /**
- * gtk_gesture_single_set_exclusive: (attributes org.gtk.Method.set_property=exclusive)
+ * gtk_gesture_single_set_exclusive:
  * @gesture: a `GtkGestureSingle`
  * @exclusive: %TRUE to make @gesture exclusive
  *
@@ -405,7 +401,7 @@ gtk_gesture_single_set_exclusive (GtkGestureSingle *gesture,
 }
 
 /**
- * gtk_gesture_single_get_button: (attributes org.gtk.Method.get_property=button)
+ * gtk_gesture_single_get_button:
  * @gesture: a `GtkGestureSingle`
  *
  * Returns the button number @gesture listens for.
@@ -427,7 +423,7 @@ gtk_gesture_single_get_button (GtkGestureSingle *gesture)
 }
 
 /**
- * gtk_gesture_single_set_button: (attributes org.gtk.Method.set_property=button)
+ * gtk_gesture_single_set_button:
  * @gesture: a `GtkGestureSingle`
  * @button: button number to listen to, or 0 for any button
  *
