@@ -64,8 +64,7 @@
 /**
  * GtkSettings:
  *
- * `GtkSettings` provides a mechanism to share global settings between
- * applications.
+ * Provides a mechanism to share global settings between applications.
  *
  * On the X window system, this sharing is realized by an
  * [XSettings](http://www.freedesktop.org/wiki/Specifications/xsettings-spec)
@@ -73,7 +72,7 @@
  * utilities that let the user change these settings.
  *
  * On Wayland, the settings are obtained either via a settings portal,
- * or by reading desktop settings from DConf.
+ * or by reading desktop settings from [class@Gio.Settings].
  *
  * On macOS, the settings are obtained from `NSUserDefaults`.
  *
@@ -100,13 +99,13 @@ typedef struct _GtkSettingsValue GtkSettingsValue;
 /*< private >
  * GtkSettingsValue:
  * @origin: Origin should be something like “filename:linenumber” for
- *    rc files, or e.g. “XProperty” for other sources.
+ *    ini files, or e.g. “XProperty” for other sources.
  * @value: Valid types are LONG, DOUBLE and STRING corresponding to
  *    the token parsed, or a GSTRING holding an unparsed statement
  */
 struct _GtkSettingsValue
 {
-  /* origin should be something like "filename:linenumber" for rc files,
+  /* origin should be something like "filename:linenumber" for ini files,
    * or e.g. "XProperty" for other sources
    */
   char *origin;
@@ -202,6 +201,7 @@ enum {
   PROP_LONG_PRESS_TIME,
   PROP_KEYNAV_USE_CARET,
   PROP_OVERLAY_SCROLLING,
+  PROP_FONT_RENDERING,
 
   NUM_PROPERTIES
 };
@@ -507,7 +507,7 @@ gtk_settings_class_init (GtkSettingsClass *class)
    * Since: 4.6
    */
   pspecs[PROP_HINT_FONT_METRICS] = g_param_spec_boolean ("gtk-hint-font-metrics", NULL, NULL,
-                                                         FALSE,
+                                                         TRUE,
                                                          GTK_PARAM_READWRITE);
 
   /**
@@ -955,6 +955,27 @@ gtk_settings_class_init (GtkSettingsClass *class)
                                                          TRUE,
                                                          GTK_PARAM_READWRITE);
 
+  /**
+   * GtkSettings:gtk-font-rendering:
+   *
+   * How GTK font rendering is set up.
+   *
+   * When set to [enum@Gtk.FontRendering.MANUAL], GTK respects the low-level
+   * font-related settings ([property@Gtk.Settings:gtk-hint-font-metrics],
+   * [property@Gtk.Settings:gtk-xft-antialias], [property@Gtk.Settings:gtk-xft-hinting],
+   * [property@Gtk.Settings:gtk-xft-hintstyle] and [property@Gtk.Settings:gtk-xft-rgba])
+   * as much as practical.
+   *
+   * When set to [enum@Gtk.FontRendering.AUTOMATIC], GTK will consider factors such
+   * as screen resolution and scale in deciding how to render fonts.
+   *
+   * Since: 4.16
+   */
+  pspecs[PROP_FONT_RENDERING] = g_param_spec_enum ("gtk-font-rendering", NULL, NULL,
+                                                   GTK_TYPE_FONT_RENDERING,
+                                                   GTK_FONT_RENDERING_AUTOMATIC,
+                                                   GTK_PARAM_READWRITE);
+
   g_object_class_install_properties (gobject_class, NUM_PROPERTIES, pspecs);
 }
 
@@ -1260,6 +1281,9 @@ gtk_settings_notify (GObject    *object,
       if (settings_update_fontconfig (settings))
         gtk_system_setting_changed (settings->display, GTK_SYSTEM_SETTING_FONT_CONFIG);
       break;
+    case PROP_FONT_RENDERING:
+      gtk_system_setting_changed (settings->display, GTK_SYSTEM_SETTING_FONT_CONFIG);
+      break;
     case PROP_ENABLE_ANIMATIONS:
       settings_invalidate_style (settings);
       break;
@@ -1320,7 +1344,7 @@ apply_queued_setting (GtkSettings      *settings,
     {
       char *debug = g_strdup_value_contents (&qvalue->value);
 
-      g_message ("%s: failed to retrieve property '%s' of type '%s' from rc file value \"%s\" of type '%s'",
+      g_message ("%s: failed to retrieve property '%s' of type '%s' from ini file value \"%s\" of type '%s'",
                  qvalue->origin ? qvalue->origin : "(for origin information, set GTK_DEBUG)",
                  pspec->name,
                  g_type_name (G_PARAM_SPEC_VALUE_TYPE (pspec)),
@@ -1354,6 +1378,7 @@ gtk_settings_set_property_value_internal (GtkSettings            *settings,
 
   if (!G_VALUE_HOLDS_LONG (&new_value->value) &&
       !G_VALUE_HOLDS_DOUBLE (&new_value->value) &&
+      !G_VALUE_HOLDS_ENUM (&new_value->value) &&
       !G_VALUE_HOLDS_STRING (&new_value->value) &&
       !G_VALUE_HOLDS (&new_value->value, G_TYPE_GSTRING))
     {
@@ -1687,7 +1712,7 @@ gtk_settings_load_from_key_file (GtkSettings       *settings,
         continue;
 
       value_type = G_PARAM_SPEC_VALUE_TYPE (pspec);
-      switch (value_type)
+      switch (G_TYPE_FUNDAMENTAL (value_type))
         {
         case G_TYPE_BOOLEAN:
           {
@@ -1723,6 +1748,35 @@ gtk_settings_load_from_key_file (GtkSettings       *settings,
             break;
           }
 
+        case G_TYPE_ENUM:
+          {
+            char *s_val;
+
+            g_value_init (&svalue.value, value_type);
+            s_val = g_key_file_get_string (keyfile, "Settings", key, &error);
+            if (!error)
+              {
+                GEnumClass *eclass;
+                GEnumValue *ev;
+
+                eclass = g_type_class_ref (value_type);
+                ev = g_enum_get_value_by_nick (eclass, s_val);
+
+                if (ev)
+                  g_value_set_enum (&svalue.value, ev->value);
+                else
+                  g_set_error (&error, G_KEY_FILE_ERROR,
+                               G_KEY_FILE_ERROR_INVALID_VALUE,
+                               "Key file contains key “%s” "
+                               "which has a value that cannot be interpreted.",
+                               key);
+
+                g_type_class_unref (eclass);
+              }
+            g_free (s_val);
+            break;
+          }
+
         default:
           {
             char *s_val;
@@ -1773,7 +1827,6 @@ settings_update_xsetting (GtkSettings *settings,
                           gboolean     force)
 {
   GType value_type;
-  GType fundamental_type;
   gboolean retval = FALSE;
 
   if (settings->property_values[pspec->param_id - 1].source == GTK_SETTINGS_SOURCE_APPLICATION)
@@ -1783,10 +1836,8 @@ settings_update_xsetting (GtkSettings *settings,
     return FALSE;
 
   value_type = G_PARAM_SPEC_VALUE_TYPE (pspec);
-  fundamental_type = G_TYPE_FUNDAMENTAL (value_type);
 
-  if ((g_value_type_transformable (G_TYPE_INT, value_type) &&
-       !(fundamental_type == G_TYPE_ENUM || fundamental_type == G_TYPE_FLAGS)) ||
+  if (g_value_type_transformable (G_TYPE_INT, value_type) ||
       g_value_type_transformable (G_TYPE_STRING, value_type) ||
       g_value_type_transformable (GDK_TYPE_RGBA, value_type))
     {
@@ -1818,7 +1869,7 @@ settings_update_xsettings (GtkSettings *settings)
 {
   int i;
 
-  for (i = 0; pspecs[i]; i++)
+  for (i = 1; i < NUM_PROPERTIES; i++)
     settings_update_xsetting (settings, pspecs[i], FALSE);
 }
 
