@@ -42,12 +42,15 @@
 /**
  * GtkSpinner:
  *
- * A `GtkSpinner` widget displays an icon-size spinning animation.
+ * Displays an icon-size spinning animation.
  *
  * It is often used as an alternative to a [class@Gtk.ProgressBar]
  * for displaying indefinite activity, instead of actual progress.
  *
- * ![An example GtkSpinner](spinner.png)
+ * <picture>
+ *   <source srcset="spinner-dark.png" media="(prefers-color-scheme: dark)">
+ *   <img alt="An example GtkSpinner" src="spinner.png">
+ * </picture>
  *
  * To start the animation, use [method@Gtk.Spinner.start], to stop it
  * use [method@Gtk.Spinner.stop].
@@ -106,7 +109,7 @@ gtk_spinner_measure (GtkWidget      *widget,
   GtkCssStyle *style;
 
   style = gtk_css_node_get_style (gtk_widget_get_css_node (widget));
-  *minimum = *natural = _gtk_css_number_value_get (style->icon->icon_size, 100);
+  *minimum = *natural = gtk_css_number_value_get (style->icon->icon_size, 100);
 }
 
 static void
@@ -160,7 +163,7 @@ gtk_spinner_css_changed (GtkWidget         *widget,
 }
 
 /**
- * gtk_spinner_get_spinning: (attributes org.gtk.Method.get_property=spinning)
+ * gtk_spinner_get_spinning:
  * @spinner: a `GtkSpinner`
  *
  * Returns whether the spinner is spinning.
@@ -176,7 +179,7 @@ gtk_spinner_get_spinning (GtkSpinner *spinner)
 }
 
 /**
- * gtk_spinner_set_spinning: (attributes org.gtk.Method.set_property=spinning)
+ * gtk_spinner_set_spinning:
  * @spinner: a `GtkSpinner`
  * @spinning: whether the spinner should be spinning
  *
@@ -250,7 +253,7 @@ gtk_spinner_class_init (GtkSpinnerClass *klass)
   widget_class->css_changed = gtk_spinner_css_changed;
 
   /**
-   * GtkSpinner:spinning: (attributes org.gtk.Property.get=gtk_spinner_get_spinning org.gtk.Property.set=gtk_spinner_set_spinning)
+   * GtkSpinner:spinning:
    *
    * Whether the spinner is spinning
    */
