@@ -111,12 +111,14 @@ struct _GtkInspectorGeneral
   GtkWidget *vulkan_layers_row;
   GtkStringList *vulkan_layers_list;
   GtkWidget *device_box;
+  GtkWidget *os_info;
   GtkWidget *gtk_version;
   GtkWidget *gdk_backend;
   GtkWidget *gsk_renderer;
   GtkWidget *pango_fontmap;
   GtkWidget *media_backend;
   GtkWidget *im_module;
+  GtkWidget *a11y_backend;
   GtkWidget *gl_backend_version;
   GtkWidget *gl_backend_version_row;
   GtkWidget *gl_backend_vendor;
@@ -254,6 +256,27 @@ set_monospace_font (GtkWidget *w)
   pango_attr_list_unref (attrs);
 }
 
+/* }}} */
+/* {{{ OS Info */
+
+static void
+init_os_info (GtkInspectorGeneral *gen)
+{
+  char *os_info = g_get_os_info (G_OS_INFO_KEY_PRETTY_NAME);
+  gtk_label_set_text (GTK_LABEL (gen->os_info), os_info);
+  g_free (os_info);
+}
+
+static void
+dump_os_info (GdkDisplay *display,
+              GString    *string)
+{
+  char *os_info = g_get_os_info (G_OS_INFO_KEY_PRETTY_NAME);
+  g_string_append_printf (string, "| Operating System | %s |\n", os_info);
+  g_free (os_info);
+}
+
+
 /* }}} */
 /* {{{ Version */
 
@@ -461,6 +484,50 @@ dump_im_module (GdkDisplay *display,
   g_string_append_printf (string, "| Input Method | %s |\n", get_im_module_kind (display));
 }
 
+/* }}} */
+/* {{{ Accessibility */
+
+static const char *
+get_a11y_backend (GdkDisplay *display)
+{
+  GtkWidget *widget;
+  GtkATContext *ctx;
+  const char *backend;
+
+  widget = gtk_label_new ("");
+  g_object_ref_sink (widget);
+  ctx = gtk_at_context_create (GTK_ACCESSIBLE_ROLE_LABEL, GTK_ACCESSIBLE (widget), display);
+
+  if (ctx == NULL)
+    backend = "none";
+  else if (strcmp (G_OBJECT_TYPE_NAME (ctx), "GtkAtSpiContext") == 0)
+    backend = "atspi";
+  else if (strcmp (G_OBJECT_TYPE_NAME (ctx), "GtkAccessKitContext") == 0)
+    backend = "accesskit";
+  else if (strcmp (G_OBJECT_TYPE_NAME (ctx), "GtkTestATContext") == 0)
+    backend = "test";
+  else
+    backend = "unknown";
+
+  g_clear_object (&ctx);
+  g_clear_object (&widget);
+
+  return backend;
+}
+
+static void
+init_a11y_backend (GtkInspectorGeneral *gen)
+{
+  gtk_label_set_label (GTK_LABEL (gen->a11y_backend), get_a11y_backend (gen->display));
+}
+
+static void
+dump_a11y_backend (GdkDisplay *display,
+                   GString    *string)
+{
+  g_string_append_printf (string, "| Accessibility backend | %s |\n", get_a11y_backend (display));
+}
+
 /* }}} */
 /* {{{ Application data */
 
@@ -1137,27 +1204,17 @@ static void
 dump_env (GdkDisplay *display,
           GString    *s)
 {
-  GString *env = g_string_new ("");
-  guint count = 0;
-
   g_string_append_printf (s, "| Prefix | %s |\n", _gtk_get_data_prefix ());
 
+  g_string_append (s, "| Environment| ");
   for (guint i = 0; i < G_N_ELEMENTS (env_list); i++)
     {
       const char *val = g_getenv (env_list[i]);
 
       if (val)
-        {
-          count++;
-          g_string_append_printf (env, "%s%s=%s", i > 0 ? "<br>" : "", env_list[i], val);
-        }
+        g_string_append_printf (s, "%s%s=%s", i > 0 ? "<br>" : "", env_list[i], val);
     }
-
-  g_string_append_printf (s, "| Environment| <details><summary>%u relevant variables</summary>", count);
-  g_string_append (s, env->str);
-  g_string_append (s, "</details> |\n");
-
-  g_string_free (env, TRUE);
+  g_string_append (s, " |\n");
 }
 
 /* }}} */
@@ -1250,6 +1307,7 @@ add_wayland_protocols (GdkDisplay          *display,
       append_wayland_protocol_row (gen, (struct wl_proxy *)d->single_pixel_buffer);
       append_wayland_protocol_row (gen, d->color ? gdk_wayland_color_get_color_manager (d->color) : NULL);
       append_wayland_protocol_row (gen, (struct wl_proxy *)d->system_bell);
+      append_wayland_protocol_row (gen, (struct wl_proxy *)d->cursor_shape);
     }
 }
 
@@ -1260,40 +1318,38 @@ dump_wayland_protocols (GdkDisplay *display,
   if (GDK_IS_WAYLAND_DISPLAY (display))
     {
       GdkWaylandDisplay *d = (GdkWaylandDisplay *) display;
-      GString *ext = g_string_new ("");
       guint count = 0;
 
-      g_string_append (string, "| Protocols | <details><summary>");
+      g_string_append (string, "| Protocols | ");
 
-      append_wayland_protocol (ext, (struct wl_proxy *)d->compositor, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->shm, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->linux_dmabuf, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->xdg_wm_base, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->zxdg_shell_v6, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->gtk_shell, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->data_device_manager, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->subcompositor, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->pointer_gestures, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->primary_selection_manager, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->tablet_manager, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->xdg_exporter, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->xdg_exporter_v2, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->xdg_importer, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->xdg_importer_v2, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->keyboard_shortcuts_inhibit, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->server_decoration_manager, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->xdg_output_manager, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->idle_inhibit_manager, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->xdg_activation, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->fractional_scale, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->viewporter, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->presentation, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->single_pixel_buffer, &count);
-      append_wayland_protocol (ext, d->color ? gdk_wayland_color_get_color_manager (d->color) : NULL, &count);
-      append_wayland_protocol (ext, (struct wl_proxy *)d->system_bell, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->compositor, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->shm, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->linux_dmabuf, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->xdg_wm_base, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->zxdg_shell_v6, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->gtk_shell, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->data_device_manager, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->subcompositor, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->pointer_gestures, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->primary_selection_manager, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->tablet_manager, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->xdg_exporter, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->xdg_exporter_v2, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->xdg_importer, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->xdg_importer_v2, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->keyboard_shortcuts_inhibit, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->server_decoration_manager, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->xdg_output_manager, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->idle_inhibit_manager, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->xdg_activation, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->fractional_scale, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->viewporter, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->presentation, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->single_pixel_buffer, &count);
+      append_wayland_protocol (string, d->color ? gdk_wayland_color_get_color_manager (d->color) : NULL, &count);
+      append_wayland_protocol (string, (struct wl_proxy *)d->system_bell, &count);
 
-      g_string_append_printf (string, "%u Protocols</summary>%s</details> |\n", count, ext->str);
-      g_string_free (ext, TRUE);
+      g_string_append (string, " |\n");
     }
 }
 #endif
@@ -2049,12 +2105,14 @@ gtk_inspector_general_class_init (GtkInspectorGeneralClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, vulkan_extensions_list);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, vulkan_layers_row);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, vulkan_layers_list);
+  gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, os_info);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, gtk_version);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, gdk_backend);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, gsk_renderer);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, pango_fontmap);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, media_backend);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, im_module);
+  gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, a11y_backend);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, gl_error);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, gl_error_row);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorGeneral, gl_version);
@@ -2101,10 +2159,12 @@ gtk_inspector_general_set_display (GtkInspectorGeneral *gen,
 {
   gen->display = display;
 
+  init_os_info (gen);
   init_version (gen);
   init_pango (gen);
   init_media (gen);
   init_im_module (gen);
+  init_a11y_backend (gen);
   init_app_id (gen);
   init_env (gen);
   init_display (gen);
@@ -2120,20 +2180,59 @@ generate_dump (GdkDisplay *display)
   GString *string;
 
   string = g_string_new ("");
+
+  g_string_append (string, "\n<details open=\"true\"><summary>General Information</summary>\n\n");
   g_string_append (string, "| Name | Value |\n");
   g_string_append (string, "| - | - |\n");
-
+  dump_os_info (display, string);
   dump_version (display, string);
   dump_pango (display, string);
   dump_media (display, string);
   dump_im_module (display, string);
+  dump_a11y_backend (display, string);
+  g_string_append (string, "\n</details>\n");
+
+  g_string_append (string, "\n<details><summary>Application</summary>\n\n");
+  g_string_append (string, "| Name | Value |\n");
+  g_string_append (string, "| - | - |\n");
   dump_app_id (display, string);
+  g_string_append (string, "\n</details>\n");
+
+  g_string_append (string, "<details><summary>Environment</summary>\n\n");
+  g_string_append (string, "| Name | Value |\n");
+  g_string_append (string, "| - | - |\n");
   dump_env (display, string);
+  g_string_append (string, "\n</details>\n");
+
+  g_string_append (string, "<details><summary>Display</summary>\n\n");
+  g_string_append (string, "| Name | Value |\n");
+  g_string_append (string, "| - | - |\n");
   dump_display (display, string);
+  g_string_append (string, "\n</details>\n");
+
+  g_string_append (string, "<details><summary>Monitors</summary>\n\n");
+  g_string_append (string, "| Name | Value |\n");
+  g_string_append (string, "| - | - |\n");
   dump_monitors (display, string);
+  g_string_append (string, "\n</details>\n");
+
+  g_string_append (string, "<details><summary>Seats</summary>\n\n");
+  g_string_append (string, "| Name | Value |\n");
+  g_string_append (string, "| - | - |\n");
   dump_seats (display, string);
+  g_string_append (string, "\n</details>\n");
+
+  g_string_append (string, "<details><summary>OpenGL</summary>\n\n");
+  g_string_append (string, "| Name | Value |\n");
+  g_string_append (string, "| - | - |\n");
   dump_gl (display, string);
+  g_string_append (string, "\n</details>\n");
+
+  g_string_append (string, "<details><summary>Vulkan</summary>\n\n");
+  g_string_append (string, "| Name | Value |\n");
+  g_string_append (string, "| - | - |\n");
   dump_vulkan (display, string);
+  g_string_append (string, "\n</details>\n");
 
   return g_string_free (string, FALSE);
 }
