@@ -64,7 +64,7 @@ struct _GtkInspectorLogs
   GtkWidget *cairo;
   GtkWidget *vulkan_gsk;
   GtkWidget *shaders;
-  GtkWidget *glyphcache;
+  GtkWidget *cache;
   GtkWidget *verbose;
 
   GtkWidget *actions;
@@ -143,7 +143,7 @@ flag_toggled (GtkWidget        *button,
   update_flag (logs->cairo, &flags, GSK_DEBUG_CAIRO);
   update_flag (logs->vulkan_gsk, &flags, GSK_DEBUG_VULKAN);
   update_flag (logs->shaders, &flags, GSK_DEBUG_SHADERS);
-  update_flag (logs->glyphcache, &flags, GSK_DEBUG_GLYPH_CACHE);
+  update_flag (logs->cache, &flags, GSK_DEBUG_CACHE);
   update_flag (logs->verbose, &flags, GSK_DEBUG_VERBOSE);
   gsk_set_debug_flags (flags);
 
@@ -205,7 +205,7 @@ gtk_inspector_logs_class_init (GtkInspectorLogsClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorLogs, cairo);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorLogs, vulkan_gsk);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorLogs, shaders);
-  gtk_widget_class_bind_template_child (widget_class, GtkInspectorLogs, glyphcache);
+  gtk_widget_class_bind_template_child (widget_class, GtkInspectorLogs, cache);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorLogs, verbose);
 
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorLogs, actions);
