@@ -1,7 +1,7 @@
 #! /bin/sh
 
 export LIBGL_ALWAYS_SOFTWARE=1
-export MESA_VK_DEVICE_SELECT=1005
+export MESA_VK_DEVICE_SELECT=1005:0
 
 version=$(head -5 meson.build | grep version | sed -e "s/[^']*'//" -e "s/'.*$//")
 release_build_dir="release_build"
