@@ -31,7 +31,7 @@
 #include <stdlib.h>
 #include <locale.h>
 
-#include "gdkpixbufutilsprivate.h"
+#include "gdktextureutilsprivate.h"
 
 static char *output_dir = NULL;
 
@@ -56,6 +56,9 @@ main (int argc, char **argv)
   GFile *dest;
   char *data;
   gsize len;
+  GHashTable *options;
+  GPtrArray *keys;
+  GPtrArray *values;
 
   setlocale (LC_ALL, "");
 
@@ -133,16 +136,28 @@ main (int argc, char **argv)
 
 
   out = g_file_replace (dest,
-			NULL, FALSE,
-			G_FILE_CREATE_REPLACE_DESTINATION,
-			NULL, &error);
+                        NULL, FALSE,
+                        G_FILE_CREATE_REPLACE_DESTINATION,
+                        NULL, &error);
   if (out == NULL)
     {
       g_printerr (_("Can’t save file %s: %s\n"), pngpath, error->message);
       return 1;
     }
 
-  if (!gdk_pixbuf_save_to_stream (symbolic, G_OUTPUT_STREAM (out), "png", NULL, &error, NULL))
+  options = gdk_pixbuf_get_options (symbolic);
+  keys = g_hash_table_get_keys_as_ptr_array (options);
+  values = g_hash_table_get_values_as_ptr_array (options);
+  g_ptr_array_add (keys, NULL);
+  g_ptr_array_add (values, NULL);
+
+  if (!gdk_pixbuf_save_to_streamv (symbolic,
+                                   G_OUTPUT_STREAM (out),
+                                   "png",
+                                   (char **) keys->pdata,
+                                   (char **) values->pdata,
+                                   NULL,
+                                   &error))
     {
       g_printerr (_("Can’t save file %s: %s\n"), pngpath, error->message);
       return 1;
@@ -154,6 +169,10 @@ main (int argc, char **argv)
       return 1;
     }
 
+  g_ptr_array_unref (keys);
+  g_ptr_array_unref (values);
+  g_hash_table_unref (options);
+
   g_object_unref (out);
   g_free (pngpath);
 
